Module alb

Module alb 

Available on crate feature alb only.
AWS Lambda event definitions for alb.

Structs

AlbTargetGroupRequest
AlbTargetGroupRequest contains data originating from the ALB Lambda target group integration
AlbTargetGroupRequestBuilder
Use builder syntax to set the inputs and finish with build().
AlbTargetGroupRequestContext
AlbTargetGroupRequestContext contains the information to identify the load balancer invoking the lambda
AlbTargetGroupRequestContextBuilder
Use builder syntax to set the inputs and finish with build().
AlbTargetGroupResponse
AlbTargetGroupResponse configures the response to be returned by the ALB Lambda target group for the request
AlbTargetGroupResponseBuilder
Use builder syntax to set the inputs and finish with build().
ElbContext
ElbContext contains the information to identify the ARN invoking the lambda
ElbContextBuilder
Use builder syntax to set the inputs and finish with build().