AlbTargetGroupRequestBuilder

Struct AlbTargetGroupRequestBuilder 

pub struct AlbTargetGroupRequestBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature alb only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> AlbTargetGroupRequestBuilder<S>

pub fn build(self) -> AlbTargetGroupRequest
where S: IsComplete,

Finish building and return the requested object

pub fn http_method( self, value: Method, ) -> AlbTargetGroupRequestBuilder<SetHttpMethod<S>>
where S::HttpMethod: IsUnset,

Required.

pub fn path(self, value: String) -> AlbTargetGroupRequestBuilder<SetPath<S>>
where S::Path: IsUnset,

Optional (Some / Option setters).

pub fn maybe_path( self, value: Option<String>, ) -> AlbTargetGroupRequestBuilder<SetPath<S>>
where S::Path: IsUnset,

Optional (Some / Option setters).

pub fn query_string_parameters( self, value: QueryMap, ) -> AlbTargetGroupRequestBuilder<SetQueryStringParameters<S>>
where S::QueryStringParameters: IsUnset,

Required.

pub fn multi_value_query_string_parameters( self, value: QueryMap, ) -> AlbTargetGroupRequestBuilder<SetMultiValueQueryStringParameters<S>>
where S::MultiValueQueryStringParameters: IsUnset,

Required.

pub fn headers( self, value: HeaderMap, ) -> AlbTargetGroupRequestBuilder<SetHeaders<S>>
where S::Headers: IsUnset,

Required.

pub fn multi_value_headers( self, value: HeaderMap, ) -> AlbTargetGroupRequestBuilder<SetMultiValueHeaders<S>>
where S::MultiValueHeaders: IsUnset,

Required.

pub fn request_context( self, value: AlbTargetGroupRequestContext, ) -> AlbTargetGroupRequestBuilder<SetRequestContext<S>>
where S::RequestContext: IsUnset,

Required.

pub fn is_base64_encoded( self, value: bool, ) -> AlbTargetGroupRequestBuilder<SetIsBase64Encoded<S>>
where S::IsBase64Encoded: IsUnset,

Required.

pub fn body(self, value: String) -> AlbTargetGroupRequestBuilder<SetBody<S>>
where S::Body: IsUnset,

Optional (Some / Option setters).

pub fn maybe_body( self, value: Option<String>, ) -> AlbTargetGroupRequestBuilder<SetBody<S>>
where S::Body: IsUnset,

Optional (Some / Option setters).

pub fn other( self, value: Map<String, Value>, ) -> AlbTargetGroupRequestBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> AlbTargetGroupRequestBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.