Module apigw

Module apigw 

Available on crate feature apigw only.
AWS Lambda event definitions for apigw.

Structs

ApiGatewayCustomAuthorizerContext
ApiGatewayCustomAuthorizerContext represents the expected format of an API Gateway custom authorizer response. Deprecated. Code should be updated to use the Authorizer map from APIGatewayRequestIdentity. Ex: Authorizer[“principalId”]
ApiGatewayCustomAuthorizerContextBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerPolicy
ApiGatewayCustomAuthorizerPolicy represents an IAM policy
ApiGatewayCustomAuthorizerPolicyBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerRequest
ApiGatewayCustomAuthorizerRequest contains data coming in to a custom API Gateway authorizer function.
ApiGatewayCustomAuthorizerRequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerRequestTypeRequest
ApiGatewayCustomAuthorizerRequestTypeRequest contains data coming in to a custom API Gateway authorizer function.
ApiGatewayCustomAuthorizerRequestTypeRequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerRequestTypeRequestContext
ApiGatewayCustomAuthorizerRequestTypeRequestContext represents the expected format of an API Gateway custom authorizer response.
ApiGatewayCustomAuthorizerRequestTypeRequestContextBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerRequestTypeRequestIdentity
ApiGatewayCustomAuthorizerRequestTypeRequestIdentity contains identity information for the request caller including certificate information if using mTLS.
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCert
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCert contains certificate information for the request caller if using mTLS.
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCertBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCertValidity
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCertValidity contains certificate validity information for the request caller if using mTLS.
ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCertValidityBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayCustomAuthorizerResponse
ApiGatewayCustomAuthorizerResponse represents the expected format of an API Gateway authorization response.
ApiGatewayCustomAuthorizerResponseBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayProxyRequest
ApiGatewayProxyRequest contains data coming from the API Gateway proxy
ApiGatewayProxyRequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayProxyRequestContext
ApiGatewayProxyRequestContext contains the information to identify the AWS account and resources invoking the Lambda function. It also includes Cognito identity information for the caller.
ApiGatewayProxyRequestContextBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayProxyResponse
ApiGatewayProxyResponse configures the response to be returned by API Gateway for the request
ApiGatewayProxyResponseBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayRequestAuthorizer
ApiGatewayRequestAuthorizer contains authorizer information for the request context.
ApiGatewayRequestAuthorizerBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayRequestAuthorizerCognitoIdentity
ApiGatewayRequestAuthorizerCognitoIdentity contains Cognito identity information for the request context.
ApiGatewayRequestAuthorizerCognitoIdentityBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayRequestAuthorizerIamDescription
ApiGatewayRequestAuthorizerIamDescription contains IAM information for the request context.
ApiGatewayRequestAuthorizerIamDescriptionBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayRequestAuthorizerJwtDescription
ApiGatewayRequestAuthorizerJwtDescription contains JWT authorizer information for the request context.
ApiGatewayRequestAuthorizerJwtDescriptionBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayRequestIdentity
ApiGatewayRequestIdentity contains identity information for the request caller.
ApiGatewayRequestIdentityBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2CustomAuthorizerIamPolicyResponse
ApiGatewayV2CustomAuthorizerIamPolicyResponseBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2CustomAuthorizerSimpleResponse
ApiGatewayV2CustomAuthorizerSimpleResponse represents the simple format of an API Gateway V2 authorization response.
ApiGatewayV2CustomAuthorizerSimpleResponseBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2CustomAuthorizerV1Request
ApiGatewayV2CustomAuthorizerV1RequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2CustomAuthorizerV1RequestTypeRequestContext
ApiGatewayV2CustomAuthorizerV1RequestTypeRequestContextBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2CustomAuthorizerV2Request
ApiGatewayV2CustomAuthorizerV2RequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpRequest
ApiGatewayV2httpRequest contains data coming from the new HTTP API Gateway
ApiGatewayV2httpRequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpRequestContext
ApiGatewayV2httpRequestContext contains the information to identify the AWS account and resources invoking the Lambda function.
ApiGatewayV2httpRequestContextAuthentication
ApiGatewayV2httpRequestContextAuthentication contains authentication context information for the request caller including client certificate information if using mTLS.
ApiGatewayV2httpRequestContextAuthenticationBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpRequestContextAuthenticationClientCert
ApiGatewayV2httpRequestContextAuthenticationClientCert contains client certificate information for the request caller if using mTLS.
ApiGatewayV2httpRequestContextAuthenticationClientCertBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpRequestContextAuthenticationClientCertValidity
ApiGatewayV2httpRequestContextAuthenticationClientCertValidity contains client certificate validity information for the request caller if using mTLS.
ApiGatewayV2httpRequestContextAuthenticationClientCertValidityBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpRequestContextBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpRequestContextHttpDescription
ApiGatewayV2httpRequestContextHttpDescription contains HTTP information for the request context.
ApiGatewayV2httpRequestContextHttpDescriptionBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayV2httpResponse
ApiGatewayV2httpResponse configures the response to be returned by API Gateway V2 for the request
ApiGatewayV2httpResponseBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayWebsocketProxyRequest
ApiGatewayWebsocketProxyRequest contains data coming from the API Gateway proxy
ApiGatewayWebsocketProxyRequestBuilder
Use builder syntax to set the inputs and finish with build().
ApiGatewayWebsocketProxyRequestContext
ApiGatewayWebsocketProxyRequestContext contains the information to identify the AWS account and resources invoking the Lambda function. It also includes Cognito identity information for the caller.
ApiGatewayWebsocketProxyRequestContextBuilder
Use builder syntax to set the inputs and finish with build().

Functions

serialize_authorizer_fields

Type Aliases

ApiGatewayV2httpRequestContextAuthorizerCognitoIdentityDeprecated
ApiGatewayV2httpRequestContextAuthorizerDescriptionDeprecated
ApiGatewayV2httpRequestContextAuthorizerIamDescriptionDeprecated
ApiGatewayV2httpRequestContextAuthorizerJwtDescriptionDeprecated