pub struct ApiGatewayCustomAuthorizerPolicyBuilder<S: State = Empty> { /* private fields */ }apigw only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ApiGatewayCustomAuthorizerPolicyBuilder<S>
impl<S: State> ApiGatewayCustomAuthorizerPolicyBuilder<S>
Sourcepub fn build(self) -> ApiGatewayCustomAuthorizerPolicywhere
S: IsComplete,
pub fn build(self) -> ApiGatewayCustomAuthorizerPolicywhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn version(
self,
value: String,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn version(
self,
value: String,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn maybe_version(
self,
value: Option<String>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn maybe_version(
self,
value: Option<String>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn statement(
self,
value: Vec<IamPolicyStatement>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetStatement<S>>where
S::Statement: IsUnset,
pub fn statement(
self,
value: Vec<IamPolicyStatement>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetStatement<S>>where
S::Statement: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ApiGatewayCustomAuthorizerPolicyBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.