#[non_exhaustive]pub struct ApiGatewayCustomAuthorizerRequest {
pub type_: Option<String>,
pub authorization_token: Option<String>,
pub method_arn: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
apigw only.Expand description
ApiGatewayCustomAuthorizerRequest contains data coming in to a custom API Gateway authorizer function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_: Option<String>method_arn: Option<String>nolint: stylecheck
other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ApiGatewayCustomAuthorizerRequest
impl ApiGatewayCustomAuthorizerRequest
Sourcepub fn builder() -> ApiGatewayCustomAuthorizerRequestBuilder
pub fn builder() -> ApiGatewayCustomAuthorizerRequestBuilder
Create an instance of ApiGatewayCustomAuthorizerRequest using the builder syntax