#[non_exhaustive]pub struct ApiGatewayCustomAuthorizerRequestTypeRequest {Show 13 fields
pub type_: Option<String>,
pub method_arn: Option<String>,
pub resource: Option<String>,
pub path: Option<String>,
pub http_method: Option<Method>,
pub headers: HeaderMap,
pub multi_value_headers: HeaderMap,
pub query_string_parameters: QueryMap,
pub multi_value_query_string_parameters: QueryMap,
pub path_parameters: HashMap<String, String>,
pub stage_variables: HashMap<String, String>,
pub request_context: ApiGatewayCustomAuthorizerRequestTypeRequestContext,
pub other: Map<String, Value>,
}Available on crate feature
apigw only.Expand description
ApiGatewayCustomAuthorizerRequestTypeRequest contains data coming in to a custom API Gateway authorizer function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_: Option<String>method_arn: Option<String>nolint: stylecheck
resource: Option<String>path: Option<String>http_method: Option<Method>headers: HeaderMapmulti_value_headers: HeaderMapquery_string_parameters: QueryMapmulti_value_query_string_parameters: QueryMappath_parameters: HashMap<String, String>stage_variables: HashMap<String, String>request_context: ApiGatewayCustomAuthorizerRequestTypeRequestContextother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ApiGatewayCustomAuthorizerRequestTypeRequest
impl ApiGatewayCustomAuthorizerRequestTypeRequest
Sourcepub fn builder() -> ApiGatewayCustomAuthorizerRequestTypeRequestBuilder
pub fn builder() -> ApiGatewayCustomAuthorizerRequestTypeRequestBuilder
Create an instance of ApiGatewayCustomAuthorizerRequestTypeRequest using the builder syntax