#[non_exhaustive]pub struct ApiGatewayProxyRequest {Show 13 fields
pub resource: Option<String>,
pub path: Option<String>,
pub http_method: Method,
pub headers: HeaderMap,
pub multi_value_headers: HeaderMap,
pub query_string_parameters: QueryMap,
pub multi_value_query_string_parameters: QueryMap,
pub path_parameters: HashMap<String, String>,
pub stage_variables: HashMap<String, String>,
pub request_context: ApiGatewayProxyRequestContext,
pub body: Option<String>,
pub is_base64_encoded: bool,
pub other: Map<String, Value>,
}Available on crate feature
apigw only.Expand description
ApiGatewayProxyRequest contains data coming from the API Gateway proxy
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource: Option<String>The resource path defined in API Gateway
path: Option<String>The url path for the caller
http_method: Methodheaders: HeaderMapmulti_value_headers: HeaderMapquery_string_parameters: QueryMapmulti_value_query_string_parameters: QueryMappath_parameters: HashMap<String, String>stage_variables: HashMap<String, String>request_context: ApiGatewayProxyRequestContextbody: Option<String>is_base64_encoded: boolother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ApiGatewayProxyRequest
impl ApiGatewayProxyRequest
Sourcepub fn builder() -> ApiGatewayProxyRequestBuilder
pub fn builder() -> ApiGatewayProxyRequestBuilder
Create an instance of ApiGatewayProxyRequest using the builder syntax