#[non_exhaustive]pub struct ApiGatewayV2httpRequestContextAuthentication {
pub client_cert: Option<ApiGatewayV2httpRequestContextAuthenticationClientCert>,
pub other: Map<String, Value>,
}Available on crate feature
apigw only.Expand description
ApiGatewayV2httpRequestContextAuthentication contains authentication context information for the request caller including client certificate information if using mTLS.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_cert: Option<ApiGatewayV2httpRequestContextAuthenticationClientCert>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ApiGatewayV2httpRequestContextAuthentication
impl ApiGatewayV2httpRequestContextAuthentication
Sourcepub fn builder() -> ApiGatewayV2httpRequestContextAuthenticationBuilder
pub fn builder() -> ApiGatewayV2httpRequestContextAuthenticationBuilder
Create an instance of ApiGatewayV2httpRequestContextAuthentication using the builder syntax