#[non_exhaustive]pub struct ApiGatewayV2httpRequestContextAuthenticationClientCert {
pub client_cert_pem: Option<String>,
pub issuer_dn: Option<String>,
pub serial_number: Option<String>,
pub subject_dn: Option<String>,
pub validity: ApiGatewayV2httpRequestContextAuthenticationClientCertValidity,
pub other: Map<String, Value>,
}Available on crate feature
apigw only.Expand description
ApiGatewayV2httpRequestContextAuthenticationClientCert contains client certificate information for the request caller if using mTLS.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_cert_pem: Option<String>issuer_dn: Option<String>serial_number: Option<String>subject_dn: Option<String>validity: ApiGatewayV2httpRequestContextAuthenticationClientCertValidityother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ApiGatewayV2httpRequestContextAuthenticationClientCert
impl ApiGatewayV2httpRequestContextAuthenticationClientCert
Sourcepub fn builder() -> ApiGatewayV2httpRequestContextAuthenticationClientCertBuilder
pub fn builder() -> ApiGatewayV2httpRequestContextAuthenticationClientCertBuilder
Create an instance of ApiGatewayV2httpRequestContextAuthenticationClientCert using the builder syntax