#[non_exhaustive]pub struct ApiGatewayV2httpRequestContextHttpDescription {
pub method: Method,
pub path: Option<String>,
pub protocol: Option<String>,
pub source_ip: Option<String>,
pub user_agent: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
apigw only.Expand description
ApiGatewayV2httpRequestContextHttpDescription contains HTTP information for the request context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.method: Methodpath: Option<String>protocol: Option<String>source_ip: Option<String>user_agent: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ApiGatewayV2httpRequestContextHttpDescription
impl ApiGatewayV2httpRequestContextHttpDescription
Sourcepub fn builder() -> ApiGatewayV2httpRequestContextHttpDescriptionBuilder
pub fn builder() -> ApiGatewayV2httpRequestContextHttpDescriptionBuilder
Create an instance of ApiGatewayV2httpRequestContextHttpDescription using the builder syntax