#[non_exhaustive]pub struct AppSyncCognitoIdentity<T1 = Value>where
T1: DeserializeOwned + Serialize,{
pub sub: Option<String>,
pub issuer: Option<String>,
pub username: Option<String>,
pub claims: HashMap<String, T1>,
pub source_ip: Vec<String>,
pub default_auth_strategy: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
appsync only.Expand description
AppSyncCognitoIdentity contains information about the caller authed via Cognito.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sub: Option<String>issuer: Option<String>username: Option<String>claims: HashMap<String, T1>source_ip: Vec<String>default_auth_strategy: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl<T1> AppSyncCognitoIdentity<T1>where
T1: DeserializeOwned + Serialize,
impl<T1> AppSyncCognitoIdentity<T1>where
T1: DeserializeOwned + Serialize,
Sourcepub fn builder() -> AppSyncCognitoIdentityBuilder<T1>
pub fn builder() -> AppSyncCognitoIdentityBuilder<T1>
Create an instance of AppSyncCognitoIdentity using the builder syntax