AppSyncDirectResolverEvent

Struct AppSyncDirectResolverEvent 

#[non_exhaustive]
pub struct AppSyncDirectResolverEvent<TArguments = Value, TSource = Value, TStash = Value>{ pub arguments: Option<TArguments>, pub identity: Option<AppSyncIdentity>, pub source: Option<TSource>, pub request: AppSyncRequest, pub info: AppSyncInfo, pub prev: Option<AppSyncPrevResult>, pub stash: TStash, pub other: Map<String, Value>, }
Available on crate feature appsync only.
AppSyncDirectResolverEvent represents the default payload structure sent by AWS AppSync when using Direct Lambda Resolvers (i.e., when both request and response mapping templates are disabled).

This structure includes the full AppSync Context object, as described in the AppSync Direct Lambda resolver reference.

It is recommended when working without VTL templates and relying on the standard AppSync-to-Lambda event format.

See also:

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
arguments: Option<TArguments>identity: Option<AppSyncIdentity>source: Option<TSource>request: AppSyncRequestinfo: AppSyncInfoprev: Option<AppSyncPrevResult>stash: TStashother: Map<String, Value>
Available on crate feature catch-all-fields only.

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

Implementations

Source

impl<TArguments, TSource, TStash> AppSyncDirectResolverEvent<TArguments, TSource, TStash>

pub fn builder() -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash>

Create an instance of AppSyncDirectResolverEvent using the builder syntax