AppSyncDirectResolverEventBuilder

Struct AppSyncDirectResolverEventBuilder 

pub struct AppSyncDirectResolverEventBuilder<TArguments = Value, TSource = Value, TStash = Value, S: State = Empty>{ /* private fields */ }
Available on crate feature appsync only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<TArguments, TSource, TStash, S: State> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, S>

pub fn build(self) -> AppSyncDirectResolverEvent<TArguments, TSource, TStash>
where S: IsComplete,

Finish building and return the requested object

pub fn arguments( self, value: TArguments, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetArguments<S>>
where S::Arguments: IsUnset,

Optional (Some / Option setters).

pub fn maybe_arguments( self, value: Option<TArguments>, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetArguments<S>>
where S::Arguments: IsUnset,

Optional (Some / Option setters).

pub fn identity( self, value: AppSyncIdentity, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetIdentity<S>>
where S::Identity: IsUnset,

Optional (Some / Option setters).

pub fn maybe_identity( self, value: Option<AppSyncIdentity>, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetIdentity<S>>
where S::Identity: IsUnset,

Optional (Some / Option setters).

pub fn source( self, value: TSource, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetSource<S>>
where S::Source: IsUnset,

Optional (Some / Option setters).

pub fn maybe_source( self, value: Option<TSource>, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetSource<S>>
where S::Source: IsUnset,

Optional (Some / Option setters).

pub fn request( self, value: AppSyncRequest, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetRequest<S>>
where S::Request: IsUnset,

Required.

pub fn info( self, value: AppSyncInfo, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetInfo<S>>
where S::Info: IsUnset,

Required.

pub fn prev( self, value: AppSyncPrevResult, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetPrev<S>>
where S::Prev: IsUnset,

Optional (Some / Option setters).

pub fn maybe_prev( self, value: Option<AppSyncPrevResult>, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetPrev<S>>
where S::Prev: IsUnset,

Optional (Some / Option setters).

pub fn stash( self, value: TStash, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetStash<S>>
where S::Stash: IsUnset,

Required.

pub fn other( self, value: Map<String, Value>, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.