pub struct AppSyncIdentityLambdaBuilder<T = Value, S: State = Empty>where
T: Serialize + DeserializeOwned,{ /* private fields */ }appsync only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<T, S: State> AppSyncIdentityLambdaBuilder<T, S>where
T: Serialize + DeserializeOwned,
impl<T, S: State> AppSyncIdentityLambdaBuilder<T, S>where
T: Serialize + DeserializeOwned,
Sourcepub fn build(self) -> AppSyncIdentityLambda<T>where
S: IsComplete,
pub fn build(self) -> AppSyncIdentityLambda<T>where
S: IsComplete,
Finish building and return the requested object
Sourcepub fn resolver_context(
self,
value: T,
) -> AppSyncIdentityLambdaBuilder<T, SetResolverContext<S>>where
S::ResolverContext: IsUnset,
pub fn resolver_context(
self,
value: T,
) -> AppSyncIdentityLambdaBuilder<T, SetResolverContext<S>>where
S::ResolverContext: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> AppSyncIdentityLambdaBuilder<T, SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> AppSyncIdentityLambdaBuilder<T, SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AppSyncIdentityLambdaBuilder<T, SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AppSyncIdentityLambdaBuilder<T, SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.