Available on crate feature
autoscaling only.Expand description
AWS Lambda event definitions for autoscaling.
Structs
- Auto
Scaling Event AutoScalingEventstruct is used to parse the json for auto scaling event types //- Auto
Scaling Event Builder - Use builder syntax to set the inputs and finish with
build().