AutoScalingEventBuilder

Struct AutoScalingEventBuilder 

pub struct AutoScalingEventBuilder<T1 = Value, S: State = Empty>{ /* private fields */ }
Available on crate feature autoscaling only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<T1, S: State> AutoScalingEventBuilder<T1, S>

pub fn build(self) -> AutoScalingEvent<T1>
where S: IsComplete,

Finish building and return the requested object

pub fn version( self, value: String, ) -> AutoScalingEventBuilder<T1, SetVersion<S>>
where S::Version: IsUnset,

Optional (Some / Option setters). The version of event data

pub fn maybe_version( self, value: Option<String>, ) -> AutoScalingEventBuilder<T1, SetVersion<S>>
where S::Version: IsUnset,

Optional (Some / Option setters). The version of event data

pub fn id(self, value: String) -> AutoScalingEventBuilder<T1, SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters). The unique ID of the event

pub fn maybe_id( self, value: Option<String>, ) -> AutoScalingEventBuilder<T1, SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters). The unique ID of the event

pub fn detail_type( self, value: String, ) -> AutoScalingEventBuilder<T1, SetDetailType<S>>
where S::DetailType: IsUnset,

Optional (Some / Option setters). Details about event type

pub fn maybe_detail_type( self, value: Option<String>, ) -> AutoScalingEventBuilder<T1, SetDetailType<S>>
where S::DetailType: IsUnset,

Optional (Some / Option setters). Details about event type

pub fn source(self, value: String) -> AutoScalingEventBuilder<T1, SetSource<S>>
where S::Source: IsUnset,

Optional (Some / Option setters). Source of the event

pub fn maybe_source( self, value: Option<String>, ) -> AutoScalingEventBuilder<T1, SetSource<S>>
where S::Source: IsUnset,

Optional (Some / Option setters). Source of the event

pub fn account_id( self, value: String, ) -> AutoScalingEventBuilder<T1, SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). AccountId

pub fn maybe_account_id( self, value: Option<String>, ) -> AutoScalingEventBuilder<T1, SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). AccountId

pub fn time( self, value: DateTime<Utc>, ) -> AutoScalingEventBuilder<T1, SetTime<S>>
where S::Time: IsUnset,

Required.

Event timestamp

pub fn region(self, value: String) -> AutoScalingEventBuilder<T1, SetRegion<S>>
where S::Region: IsUnset,

Optional (Some / Option setters). Region of event

pub fn maybe_region( self, value: Option<String>, ) -> AutoScalingEventBuilder<T1, SetRegion<S>>
where S::Region: IsUnset,

Optional (Some / Option setters). Region of event

pub fn resources( self, value: Vec<String>, ) -> AutoScalingEventBuilder<T1, SetResources<S>>
where S::Resources: IsUnset,

Required.

Information about resources impacted by event

pub fn detail( self, value: HashMap<String, T1>, ) -> AutoScalingEventBuilder<T1, SetDetail<S>>
where S::Detail: IsUnset,

Required.

pub fn other( self, value: Map<String, Value>, ) -> AutoScalingEventBuilder<T1, SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> AutoScalingEventBuilder<T1, SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.