Module bedrock_agent_runtime

Module bedrock_agent_runtime 

Available on crate feature bedrock_agent_runtime only.
AWS Lambda event definitions for agent for amazon bedrock

Structs

Agent
AgentBuilder
Use builder syntax to set the inputs and finish with build().
AgentEvent
The Event sent to Lambda from Agents for Amazon Bedrock.
AgentEventBuilder
Use builder syntax to set the inputs and finish with build().
Content
ContentBuilder
Use builder syntax to set the inputs and finish with build().
Parameter
ParameterBuilder
Use builder syntax to set the inputs and finish with build().
Property
PropertyBuilder
Use builder syntax to set the inputs and finish with build().
RequestBody
RequestBodyBuilder
Use builder syntax to set the inputs and finish with build().