Module cloudformation

Module cloudformation 

Available on crate feature cloudformation only.
AWS Lambda event definitions for cloudformation.

Modules

provider
These events are to be used with the CDK custom resource provider framework.

Structs

CloudFormationCustomResourceResponse
CloudFormationCustomResourceResponseBuilder
Use builder syntax to set the inputs and finish with build().
CreateRequest
CreateRequestBuilder
Use builder syntax to set the inputs and finish with build().
DeleteRequest
DeleteRequestBuilder
Use builder syntax to set the inputs and finish with build().
UpdateRequest
UpdateRequestBuilder
Use builder syntax to set the inputs and finish with build().

Enums

CloudFormationCustomResourceRequest
CloudFormationCustomResourceResponseStatus