DeleteRequest

Struct DeleteRequest 

#[non_exhaustive]
pub struct DeleteRequest<P2 = Value>{ pub service_token: Option<String>, pub request_id: String, pub response_url: String, pub stack_id: String, pub resource_type: String, pub logical_resource_id: String, pub physical_resource_id: String, pub resource_properties: P2, pub other: Map<String, Value>, }
Available on crate feature cloudformation only.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
service_token: Option<String>request_id: Stringresponse_url: Stringstack_id: Stringresource_type: Stringlogical_resource_id: Stringphysical_resource_id: Stringresource_properties: P2other: Map<String, Value>
Available on crate feature catch-all-fields only.

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

Implementations

Source

impl<P2> DeleteRequest<P2>

pub fn builder() -> DeleteRequestBuilder<P2>

Create an instance of DeleteRequest using the builder syntax