#[non_exhaustive]pub struct CloudWatchAlarmStateTriggeringAlarm {
pub arn: String,
pub state: CloudWatchAlarmStateTriggeringAlarmState,
pub other: Map<String, Value>,
}Available on crate feature
cloudwatch_alarms only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: Stringstate: CloudWatchAlarmStateTriggeringAlarmStateother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl CloudWatchAlarmStateTriggeringAlarm
impl CloudWatchAlarmStateTriggeringAlarm
Sourcepub fn builder() -> CloudWatchAlarmStateTriggeringAlarmBuilder
pub fn builder() -> CloudWatchAlarmStateTriggeringAlarmBuilder
Create an instance of CloudWatchAlarmStateTriggeringAlarm using the builder syntax