pub struct CloudWatchMetricDefinitionBuilder<S: State = Empty> { /* private fields */ }cloudwatch_alarms only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CloudWatchMetricDefinitionBuilder<S>
impl<S: State> CloudWatchMetricDefinitionBuilder<S>
Sourcepub fn build(self) -> CloudWatchMetricDefinitionwhere
S: IsComplete,
pub fn build(self) -> CloudWatchMetricDefinitionwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn id(self, value: String) -> CloudWatchMetricDefinitionBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: String) -> CloudWatchMetricDefinitionBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Sourcepub fn return_data(
self,
value: bool,
) -> CloudWatchMetricDefinitionBuilder<SetReturnData<S>>where
S::ReturnData: IsUnset,
pub fn return_data(
self,
value: bool,
) -> CloudWatchMetricDefinitionBuilder<SetReturnData<S>>where
S::ReturnData: IsUnset,
Required.
Sourcepub fn metric_stat(
self,
value: CloudWatchMetricStatDefinition,
) -> CloudWatchMetricDefinitionBuilder<SetMetricStat<S>>where
S::MetricStat: IsUnset,
pub fn metric_stat(
self,
value: CloudWatchMetricStatDefinition,
) -> CloudWatchMetricDefinitionBuilder<SetMetricStat<S>>where
S::MetricStat: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CloudWatchMetricDefinitionBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CloudWatchMetricDefinitionBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CloudWatchMetricDefinitionBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CloudWatchMetricDefinitionBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.