pub struct OnBehalfOfBuilder<S: State = Empty> { /* private fields */ }cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> OnBehalfOfBuilder<S>
impl<S: State> OnBehalfOfBuilder<S>
Sourcepub fn build(self) -> OnBehalfOfwhere
S: IsComplete,
pub fn build(self) -> OnBehalfOfwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn user_id(self, value: String) -> OnBehalfOfBuilder<SetUserId<S>>where
S::UserId: IsUnset,
pub fn user_id(self, value: String) -> OnBehalfOfBuilder<SetUserId<S>>where
S::UserId: IsUnset,
Required.
Sourcepub fn identity_store_arn(
self,
value: String,
) -> OnBehalfOfBuilder<SetIdentityStoreArn<S>>where
S::IdentityStoreArn: IsUnset,
pub fn identity_store_arn(
self,
value: String,
) -> OnBehalfOfBuilder<SetIdentityStoreArn<S>>where
S::IdentityStoreArn: IsUnset,
Required.
Sourcepub fn other(self, value: Map<String, Value>) -> OnBehalfOfBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(self, value: Map<String, Value>) -> OnBehalfOfBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> OnBehalfOfBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> OnBehalfOfBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.