#[non_exhaustive]pub struct SessionContext {
pub session_issuer: Option<SessionIssuer>,
pub web_id_federation_data: Option<WebIdFederationData>,
pub attributes: Attributes,
pub source_identity: Option<String>,
pub ec2_role_delivery: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
cloudwatch_events only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_issuer: Option<SessionIssuer>web_id_federation_data: Option<WebIdFederationData>attributes: Attributessource_identity: Option<String>ec2_role_delivery: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl SessionContext
impl SessionContext
Sourcepub fn builder() -> SessionContextBuilder
pub fn builder() -> SessionContextBuilder
Create an instance of SessionContext using the builder syntax