UserIdentityBuilder

Struct UserIdentityBuilder 

pub struct UserIdentityBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature cloudwatch_events only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> UserIdentityBuilder<S>

pub fn build(self) -> UserIdentity
where S: IsComplete,

Finish building and return the requested object

pub fn type(self, value: String) -> UserIdentityBuilder<SetType<S>>
where S::Type: IsUnset,

Required.

pub fn account_id(self, value: String) -> UserIdentityBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_account_id( self, value: Option<String>, ) -> UserIdentityBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters).

pub fn arn(self, value: String) -> UserIdentityBuilder<SetArn<S>>
where S::Arn: IsUnset,

Optional (Some / Option setters).

pub fn maybe_arn(self, value: Option<String>) -> UserIdentityBuilder<SetArn<S>>
where S::Arn: IsUnset,

Optional (Some / Option setters).

pub fn credential_id( self, value: String, ) -> UserIdentityBuilder<SetCredentialId<S>>
where S::CredentialId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_credential_id( self, value: Option<String>, ) -> UserIdentityBuilder<SetCredentialId<S>>
where S::CredentialId: IsUnset,

Optional (Some / Option setters).

pub fn invoked_by(self, value: String) -> UserIdentityBuilder<SetInvokedBy<S>>
where S::InvokedBy: IsUnset,

Optional (Some / Option setters).

pub fn maybe_invoked_by( self, value: Option<String>, ) -> UserIdentityBuilder<SetInvokedBy<S>>
where S::InvokedBy: IsUnset,

Optional (Some / Option setters).

pub fn principal_id( self, value: String, ) -> UserIdentityBuilder<SetPrincipalId<S>>
where S::PrincipalId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_principal_id( self, value: Option<String>, ) -> UserIdentityBuilder<SetPrincipalId<S>>
where S::PrincipalId: IsUnset,

Optional (Some / Option setters).

pub fn session_context( self, value: SessionContext, ) -> UserIdentityBuilder<SetSessionContext<S>>
where S::SessionContext: IsUnset,

Optional (Some / Option setters).

pub fn maybe_session_context( self, value: Option<SessionContext>, ) -> UserIdentityBuilder<SetSessionContext<S>>
where S::SessionContext: IsUnset,

Optional (Some / Option setters).

pub fn user_name(self, value: String) -> UserIdentityBuilder<SetUserName<S>>
where S::UserName: IsUnset,

Optional (Some / Option setters).

pub fn maybe_user_name( self, value: Option<String>, ) -> UserIdentityBuilder<SetUserName<S>>
where S::UserName: IsUnset,

Optional (Some / Option setters).

pub fn on_behalf_of( self, value: OnBehalfOf, ) -> UserIdentityBuilder<SetOnBehalfOf<S>>
where S::OnBehalfOf: IsUnset,

Optional (Some / Option setters).

pub fn maybe_on_behalf_of( self, value: Option<OnBehalfOf>, ) -> UserIdentityBuilder<SetOnBehalfOf<S>>
where S::OnBehalfOf: IsUnset,

Optional (Some / Option setters).

pub fn other( self, value: Map<String, Value>, ) -> UserIdentityBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> UserIdentityBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.