#[non_exhaustive]pub struct MatchmakingCancelled {
pub reason: String,
pub tickets: Vec<Ticket>,
pub rule_evaluation_metrics: Vec<RuleEvaluationMetric>,
pub type: String,
pub message: String,
pub game_session_info: GameSessionInfo,
pub other: Map<String, Value>,
}Available on crate feature
cloudwatch_events only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reason: Stringtickets: Vec<Ticket>rule_evaluation_metrics: Vec<RuleEvaluationMetric>type: Stringmessage: Stringgame_session_info: GameSessionInfoother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl MatchmakingCancelled
impl MatchmakingCancelled
Sourcepub fn builder() -> MatchmakingCancelledBuilder
pub fn builder() -> MatchmakingCancelledBuilder
Create an instance of MatchmakingCancelled using the builder syntax