pub struct CrawlerStartedBuilder<S: State = Empty> { /* private fields */ }cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CrawlerStartedBuilder<S>
impl<S: State> CrawlerStartedBuilder<S>
Sourcepub fn build(self) -> CrawlerStartedwhere
S: IsComplete,
pub fn build(self) -> CrawlerStartedwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn account_id(self, value: String) -> CrawlerStartedBuilder<SetAccountId<S>>where
S::AccountId: IsUnset,
pub fn account_id(self, value: String) -> CrawlerStartedBuilder<SetAccountId<S>>where
S::AccountId: IsUnset,
Required.
Sourcepub fn crawler_name(
self,
value: String,
) -> CrawlerStartedBuilder<SetCrawlerName<S>>where
S::CrawlerName: IsUnset,
pub fn crawler_name(
self,
value: String,
) -> CrawlerStartedBuilder<SetCrawlerName<S>>where
S::CrawlerName: IsUnset,
Required.
Sourcepub fn start_time(self, value: String) -> CrawlerStartedBuilder<SetStartTime<S>>where
S::StartTime: IsUnset,
pub fn start_time(self, value: String) -> CrawlerStartedBuilder<SetStartTime<S>>where
S::StartTime: IsUnset,
Required.
Sourcepub fn state(self, value: String) -> CrawlerStartedBuilder<SetState<S>>where
S::State: IsUnset,
pub fn state(self, value: String) -> CrawlerStartedBuilder<SetState<S>>where
S::State: IsUnset,
Required.
Sourcepub fn message(self, value: String) -> CrawlerStartedBuilder<SetMessage<S>>where
S::Message: IsUnset,
pub fn message(self, value: String) -> CrawlerStartedBuilder<SetMessage<S>>where
S::Message: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CrawlerStartedBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CrawlerStartedBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CrawlerStartedBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CrawlerStartedBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.