#[non_exhaustive]pub struct JobRunStateChange {
pub job_name: String,
pub severity: String,
pub state: String,
pub job_run_id: String,
pub message: String,
pub other: Map<String, Value>,
}Available on crate feature
cloudwatch_events only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_name: Stringseverity: Stringstate: Stringjob_run_id: Stringmessage: Stringother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl JobRunStateChange
impl JobRunStateChange
Sourcepub fn builder() -> JobRunStateChangeBuilder
pub fn builder() -> JobRunStateChangeBuilder
Create an instance of JobRunStateChange using the builder syntax