pub struct JobRunStatusBuilder<S: State = Empty> { /* private fields */ }cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> JobRunStatusBuilder<S>
impl<S: State> JobRunStatusBuilder<S>
Sourcepub fn build(self) -> JobRunStatuswhere
S: IsComplete,
pub fn build(self) -> JobRunStatuswhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn job_name(self, value: String) -> JobRunStatusBuilder<SetJobName<S>>where
S::JobName: IsUnset,
pub fn job_name(self, value: String) -> JobRunStatusBuilder<SetJobName<S>>where
S::JobName: IsUnset,
Required.
Sourcepub fn severity(self, value: String) -> JobRunStatusBuilder<SetSeverity<S>>where
S::Severity: IsUnset,
pub fn severity(self, value: String) -> JobRunStatusBuilder<SetSeverity<S>>where
S::Severity: IsUnset,
Required.
Sourcepub fn notification_condition(
self,
value: NotificationCondition,
) -> JobRunStatusBuilder<SetNotificationCondition<S>>where
S::NotificationCondition: IsUnset,
pub fn notification_condition(
self,
value: NotificationCondition,
) -> JobRunStatusBuilder<SetNotificationCondition<S>>where
S::NotificationCondition: IsUnset,
Required.
Sourcepub fn state(self, value: String) -> JobRunStatusBuilder<SetState<S>>where
S::State: IsUnset,
pub fn state(self, value: String) -> JobRunStatusBuilder<SetState<S>>where
S::State: IsUnset,
Required.
Sourcepub fn job_run_id(self, value: String) -> JobRunStatusBuilder<SetJobRunId<S>>where
S::JobRunId: IsUnset,
pub fn job_run_id(self, value: String) -> JobRunStatusBuilder<SetJobRunId<S>>where
S::JobRunId: IsUnset,
Required.
Sourcepub fn message(self, value: String) -> JobRunStatusBuilder<SetMessage<S>>where
S::Message: IsUnset,
pub fn message(self, value: String) -> JobRunStatusBuilder<SetMessage<S>>where
S::Message: IsUnset,
Required.
Sourcepub fn started_on(self, value: String) -> JobRunStatusBuilder<SetStartedOn<S>>where
S::StartedOn: IsUnset,
pub fn started_on(self, value: String) -> JobRunStatusBuilder<SetStartedOn<S>>where
S::StartedOn: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> JobRunStatusBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> JobRunStatusBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> JobRunStatusBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> JobRunStatusBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.