#[non_exhaustive]pub struct Event {
pub event_arn: String,
pub service: String,
pub event_type_code: String,
pub event_type_category: String,
pub start_time: String,
pub end_time: String,
pub event_description: Vec<EventDescription>,
pub affected_entities: Option<Vec<Entity>>,
pub other: Map<String, Value>,
}Available on crate feature
cloudwatch_events only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_arn: Stringservice: Stringevent_type_code: Stringevent_type_category: Stringstart_time: Stringend_time: Stringevent_description: Vec<EventDescription>affected_entities: Option<Vec<Entity>>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations