pub struct AclBuilder<S: State = Empty> { /* private fields */ }Available on crate feature
cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> AclBuilder<S>
impl<S: State> AclBuilder<S>
Sourcepub fn secret_bucket_name(
self,
value: Vec<SecretBucketName>,
) -> AclBuilder<SetSecretBucketName<S>>where
S::SecretBucketName: IsUnset,
pub fn secret_bucket_name(
self,
value: Vec<SecretBucketName>,
) -> AclBuilder<SetSecretBucketName<S>>where
S::SecretBucketName: IsUnset,
Required.
Sourcepub fn other(self, value: Map<String, Value>) -> AclBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(self, value: Map<String, Value>) -> AclBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AclBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AclBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.