EC2StateManagerAssociationStateChangeBuilder

Struct EC2StateManagerAssociationStateChangeBuilder 

pub struct EC2StateManagerAssociationStateChangeBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature cloudwatch_events only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> EC2StateManagerAssociationStateChangeBuilder<S>

pub fn build(self) -> EC2StateManagerAssociationStateChange
where S: IsComplete,

Finish building and return the requested object

pub fn association_id( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationId<S>>
where S::AssociationId: IsUnset,

Required.

pub fn document_name( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetDocumentName<S>>
where S::DocumentName: IsUnset,

Required.

pub fn association_version( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationVersion<S>>
where S::AssociationVersion: IsUnset,

Required.

pub fn document_version( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetDocumentVersion<S>>
where S::DocumentVersion: IsUnset,

Required.

pub fn targets( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetTargets<S>>
where S::Targets: IsUnset,

Required.

pub fn creation_date( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetCreationDate<S>>
where S::CreationDate: IsUnset,

Required.

pub fn last_successful_execution_date( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetLastSuccessfulExecutionDate<S>>
where S::LastSuccessfulExecutionDate: IsUnset,

Required.

pub fn last_execution_date( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetLastExecutionDate<S>>
where S::LastExecutionDate: IsUnset,

Required.

pub fn last_updated_date( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetLastUpdatedDate<S>>
where S::LastUpdatedDate: IsUnset,

Required.

pub fn status( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetStatus<S>>
where S::Status: IsUnset,

Required.

pub fn association_status_aggregated_count( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationStatusAggregatedCount<S>>
where S::AssociationStatusAggregatedCount: IsUnset,

Required.

pub fn schedule_expression( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetScheduleExpression<S>>
where S::ScheduleExpression: IsUnset,

Required.

pub fn association_cwe_version( self, value: String, ) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationCweVersion<S>>
where S::AssociationCweVersion: IsUnset,

Required.

pub fn other( self, value: Map<String, Value>, ) -> EC2StateManagerAssociationStateChangeBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> EC2StateManagerAssociationStateChangeBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.