pub struct MaintenanceWindowTargetRegistrationBuilder<S: State = Empty> { /* private fields */ }cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> MaintenanceWindowTargetRegistrationBuilder<S>
impl<S: State> MaintenanceWindowTargetRegistrationBuilder<S>
Sourcepub fn build(self) -> MaintenanceWindowTargetRegistrationwhere
S: IsComplete,
pub fn build(self) -> MaintenanceWindowTargetRegistrationwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn window_target_id(
self,
value: String,
) -> MaintenanceWindowTargetRegistrationBuilder<SetWindowTargetId<S>>where
S::WindowTargetId: IsUnset,
pub fn window_target_id(
self,
value: String,
) -> MaintenanceWindowTargetRegistrationBuilder<SetWindowTargetId<S>>where
S::WindowTargetId: IsUnset,
Required.
Sourcepub fn window_id(
self,
value: String,
) -> MaintenanceWindowTargetRegistrationBuilder<SetWindowId<S>>where
S::WindowId: IsUnset,
pub fn window_id(
self,
value: String,
) -> MaintenanceWindowTargetRegistrationBuilder<SetWindowId<S>>where
S::WindowId: IsUnset,
Required.
Sourcepub fn status(
self,
value: String,
) -> MaintenanceWindowTargetRegistrationBuilder<SetStatus<S>>where
S::Status: IsUnset,
pub fn status(
self,
value: String,
) -> MaintenanceWindowTargetRegistrationBuilder<SetStatus<S>>where
S::Status: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> MaintenanceWindowTargetRegistrationBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> MaintenanceWindowTargetRegistrationBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> MaintenanceWindowTargetRegistrationBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> MaintenanceWindowTargetRegistrationBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.