CodeCommitRecordBuilder

Struct CodeCommitRecordBuilder 

pub struct CodeCommitRecordBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature code_commit only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CodeCommitRecordBuilder<S>

pub fn build(self) -> CodeCommitRecord
where S: IsComplete,

Finish building and return the requested object

pub fn event_id(self, value: String) -> CodeCommitRecordBuilder<SetEventId<S>>
where S::EventId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_id( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventId<S>>
where S::EventId: IsUnset,

Optional (Some / Option setters).

pub fn event_version( self, value: String, ) -> CodeCommitRecordBuilder<SetEventVersion<S>>
where S::EventVersion: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_version( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventVersion<S>>
where S::EventVersion: IsUnset,

Optional (Some / Option setters).

pub fn event_time( self, value: CodeCommitEventTime, ) -> CodeCommitRecordBuilder<SetEventTime<S>>
where S::EventTime: IsUnset,

Required.

pub fn event_trigger_name( self, value: String, ) -> CodeCommitRecordBuilder<SetEventTriggerName<S>>
where S::EventTriggerName: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_trigger_name( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventTriggerName<S>>
where S::EventTriggerName: IsUnset,

Optional (Some / Option setters).

pub fn event_part_number( self, value: u64, ) -> CodeCommitRecordBuilder<SetEventPartNumber<S>>
where S::EventPartNumber: IsUnset,

Required.

pub fn code_commit( self, value: CodeCommitCodeCommit, ) -> CodeCommitRecordBuilder<SetCodeCommit<S>>
where S::CodeCommit: IsUnset,

Required.

pub fn event_name( self, value: String, ) -> CodeCommitRecordBuilder<SetEventName<S>>
where S::EventName: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_name( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventName<S>>
where S::EventName: IsUnset,

Optional (Some / Option setters).

pub fn event_trigger_config_id( self, value: String, ) -> CodeCommitRecordBuilder<SetEventTriggerConfigId<S>>
where S::EventTriggerConfigId: IsUnset,

Optional (Some / Option setters). nolint: stylecheck

pub fn maybe_event_trigger_config_id( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventTriggerConfigId<S>>
where S::EventTriggerConfigId: IsUnset,

Optional (Some / Option setters). nolint: stylecheck

pub fn event_source_arn( self, value: String, ) -> CodeCommitRecordBuilder<SetEventSourceArn<S>>
where S::EventSourceArn: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_source_arn( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventSourceArn<S>>
where S::EventSourceArn: IsUnset,

Optional (Some / Option setters).

pub fn user_identity_arn( self, value: String, ) -> CodeCommitRecordBuilder<SetUserIdentityArn<S>>
where S::UserIdentityArn: IsUnset,

Optional (Some / Option setters).

pub fn maybe_user_identity_arn( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetUserIdentityArn<S>>
where S::UserIdentityArn: IsUnset,

Optional (Some / Option setters).

pub fn event_source( self, value: String, ) -> CodeCommitRecordBuilder<SetEventSource<S>>
where S::EventSource: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_source( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetEventSource<S>>
where S::EventSource: IsUnset,

Optional (Some / Option setters).

pub fn aws_region( self, value: String, ) -> CodeCommitRecordBuilder<SetAwsRegion<S>>
where S::AwsRegion: IsUnset,

Optional (Some / Option setters).

pub fn maybe_aws_region( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetAwsRegion<S>>
where S::AwsRegion: IsUnset,

Optional (Some / Option setters).

pub fn event_total_parts( self, value: u64, ) -> CodeCommitRecordBuilder<SetEventTotalParts<S>>
where S::EventTotalParts: IsUnset,

Required.

pub fn custom_data( self, value: String, ) -> CodeCommitRecordBuilder<SetCustomData<S>>
where S::CustomData: IsUnset,

Optional (Some / Option setters).

pub fn maybe_custom_data( self, value: Option<String>, ) -> CodeCommitRecordBuilder<SetCustomData<S>>
where S::CustomData: IsUnset,

Optional (Some / Option setters).

pub fn other( self, value: Map<String, Value>, ) -> CodeCommitRecordBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> CodeCommitRecordBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.