#[non_exhaustive]pub struct CodeDeployEventDetail {
pub instance_group_id: Option<String>,
pub instance_id: Option<String>,
pub region: Option<String>,
pub application: Option<String>,
pub deployment_id: Option<String>,
pub state: CodeDeployDeploymentState,
pub deployment_group: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
codedeploy only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_group_id: Option<String>InstanceGroupID is the ID of the instance group.
instance_id: Option<String>InstanceID is the id of the instance. This field is non-empty only if the DetailType of the complete event is CodeDeployInstanceEventDetailType.
region: Option<String>Region is the AWS region that the event originated from.
application: Option<String>Application is the name of the CodeDeploy application.
deployment_id: Option<String>DeploymentID is the id of the deployment.
state: CodeDeployDeploymentStateState is the new state of the deployment.
deployment_group: Option<String>DeploymentGroup is the name of the deployment group.
other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl CodeDeployEventDetail
impl CodeDeployEventDetail
Sourcepub fn builder() -> CodeDeployEventDetailBuilder
pub fn builder() -> CodeDeployEventDetailBuilder
Create an instance of CodeDeployEventDetail using the builder syntax