CodePipelineEventDetailBuilder

Struct CodePipelineEventDetailBuilder 

pub struct CodePipelineEventDetailBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature codepipeline_cloudwatch only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CodePipelineEventDetailBuilder<S>

pub fn build(self) -> CodePipelineEventDetail
where S: IsComplete,

Finish building and return the requested object

pub fn pipeline( self, value: String, ) -> CodePipelineEventDetailBuilder<SetPipeline<S>>
where S::Pipeline: IsUnset,

Optional (Some / Option setters).

pub fn maybe_pipeline( self, value: Option<String>, ) -> CodePipelineEventDetailBuilder<SetPipeline<S>>
where S::Pipeline: IsUnset,

Optional (Some / Option setters).

pub fn version( self, value: i64, ) -> CodePipelineEventDetailBuilder<SetVersion<S>>
where S::Version: IsUnset,

Required.

From live testing this is always int64 not string as documented

pub fn execution_id( self, value: String, ) -> CodePipelineEventDetailBuilder<SetExecutionId<S>>
where S::ExecutionId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_execution_id( self, value: Option<String>, ) -> CodePipelineEventDetailBuilder<SetExecutionId<S>>
where S::ExecutionId: IsUnset,

Optional (Some / Option setters).

pub fn stage(self, value: String) -> CodePipelineEventDetailBuilder<SetStage<S>>
where S::Stage: IsUnset,

Optional (Some / Option setters).

pub fn maybe_stage( self, value: Option<String>, ) -> CodePipelineEventDetailBuilder<SetStage<S>>
where S::Stage: IsUnset,

Optional (Some / Option setters).

pub fn action( self, value: String, ) -> CodePipelineEventDetailBuilder<SetAction<S>>
where S::Action: IsUnset,

Optional (Some / Option setters).

pub fn maybe_action( self, value: Option<String>, ) -> CodePipelineEventDetailBuilder<SetAction<S>>
where S::Action: IsUnset,

Optional (Some / Option setters).

pub fn state( self, value: CodePipelineState, ) -> CodePipelineEventDetailBuilder<SetState<S>>
where S::State: IsUnset,

Required.

pub fn region( self, value: String, ) -> CodePipelineEventDetailBuilder<SetRegion<S>>
where S::Region: IsUnset,

Optional (Some / Option setters).

pub fn maybe_region( self, value: Option<String>, ) -> CodePipelineEventDetailBuilder<SetRegion<S>>
where S::Region: IsUnset,

Optional (Some / Option setters).

pub fn type_( self, value: CodePipelineEventDetailType, ) -> CodePipelineEventDetailBuilder<SetType<S>>
where S::Type: IsUnset,

Optional (Some / Option setters).

pub fn maybe_type_( self, value: Option<CodePipelineEventDetailType>, ) -> CodePipelineEventDetailBuilder<SetType<S>>
where S::Type: IsUnset,

Optional (Some / Option setters).

pub fn other( self, value: Map<String, Value>, ) -> CodePipelineEventDetailBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> CodePipelineEventDetailBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.