#[non_exhaustive]pub struct CodePipelineArtifactCredentials {
pub secret_access_key: Option<String>,
pub session_token: Option<String>,
pub access_key_id: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
codepipeline_job only.Expand description
CodePipelineArtifactCredentials represents CodePipeline artifact credentials
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secret_access_key: Option<String>session_token: Option<String>access_key_id: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl CodePipelineArtifactCredentials
impl CodePipelineArtifactCredentials
Sourcepub fn builder() -> CodePipelineArtifactCredentialsBuilder
pub fn builder() -> CodePipelineArtifactCredentialsBuilder
Create an instance of CodePipelineArtifactCredentials using the builder syntax