pub struct CodePipelineConfigurationBuilder<S: State = Empty> { /* private fields */ }codepipeline_job only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CodePipelineConfigurationBuilder<S>
impl<S: State> CodePipelineConfigurationBuilder<S>
Sourcepub fn build(self) -> CodePipelineConfigurationwhere
S: IsComplete,
pub fn build(self) -> CodePipelineConfigurationwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn function_name(
self,
value: String,
) -> CodePipelineConfigurationBuilder<SetFunctionName<S>>where
S::FunctionName: IsUnset,
pub fn function_name(
self,
value: String,
) -> CodePipelineConfigurationBuilder<SetFunctionName<S>>where
S::FunctionName: IsUnset,
Sourcepub fn maybe_function_name(
self,
value: Option<String>,
) -> CodePipelineConfigurationBuilder<SetFunctionName<S>>where
S::FunctionName: IsUnset,
pub fn maybe_function_name(
self,
value: Option<String>,
) -> CodePipelineConfigurationBuilder<SetFunctionName<S>>where
S::FunctionName: IsUnset,
Sourcepub fn user_parameters(
self,
value: String,
) -> CodePipelineConfigurationBuilder<SetUserParameters<S>>where
S::UserParameters: IsUnset,
pub fn user_parameters(
self,
value: String,
) -> CodePipelineConfigurationBuilder<SetUserParameters<S>>where
S::UserParameters: IsUnset,
Sourcepub fn maybe_user_parameters(
self,
value: Option<String>,
) -> CodePipelineConfigurationBuilder<SetUserParameters<S>>where
S::UserParameters: IsUnset,
pub fn maybe_user_parameters(
self,
value: Option<String>,
) -> CodePipelineConfigurationBuilder<SetUserParameters<S>>where
S::UserParameters: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CodePipelineConfigurationBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CodePipelineConfigurationBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CodePipelineConfigurationBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CodePipelineConfigurationBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.