CodePipelineJobBuilder

Struct CodePipelineJobBuilder 

pub struct CodePipelineJobBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature codepipeline_job only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CodePipelineJobBuilder<S>

pub fn build(self) -> CodePipelineJob
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: String) -> CodePipelineJobBuilder<SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters).

pub fn maybe_id(self, value: Option<String>) -> CodePipelineJobBuilder<SetId<S>>
where S::Id: IsUnset,

Optional (Some / Option setters).

pub fn account_id( self, value: String, ) -> CodePipelineJobBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_account_id( self, value: Option<String>, ) -> CodePipelineJobBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters).

pub fn data(self, value: CodePipelineData) -> CodePipelineJobBuilder<SetData<S>>
where S::Data: IsUnset,

Required.

pub fn other( self, value: Map<String, Value>, ) -> CodePipelineJobBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> CodePipelineJobBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.