CognitoEventBuilder

Struct CognitoEventBuilder 

pub struct CognitoEventBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature cognito only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CognitoEventBuilder<S>

pub fn build(self) -> CognitoEvent
where S: IsComplete,

Finish building and return the requested object

pub fn dataset_name( self, value: String, ) -> CognitoEventBuilder<SetDatasetName<S>>
where S::DatasetName: IsUnset,

Optional (Some / Option setters).

pub fn maybe_dataset_name( self, value: Option<String>, ) -> CognitoEventBuilder<SetDatasetName<S>>
where S::DatasetName: IsUnset,

Optional (Some / Option setters).

pub fn dataset_records( self, value: HashMap<String, CognitoDatasetRecord>, ) -> CognitoEventBuilder<SetDatasetRecords<S>>
where S::DatasetRecords: IsUnset,

Required.

pub fn event_type(self, value: String) -> CognitoEventBuilder<SetEventType<S>>
where S::EventType: IsUnset,

Optional (Some / Option setters).

pub fn maybe_event_type( self, value: Option<String>, ) -> CognitoEventBuilder<SetEventType<S>>
where S::EventType: IsUnset,

Optional (Some / Option setters).

pub fn identity_id(self, value: String) -> CognitoEventBuilder<SetIdentityId<S>>
where S::IdentityId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_identity_id( self, value: Option<String>, ) -> CognitoEventBuilder<SetIdentityId<S>>
where S::IdentityId: IsUnset,

Optional (Some / Option setters).

pub fn identity_pool_id( self, value: String, ) -> CognitoEventBuilder<SetIdentityPoolId<S>>
where S::IdentityPoolId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_identity_pool_id( self, value: Option<String>, ) -> CognitoEventBuilder<SetIdentityPoolId<S>>
where S::IdentityPoolId: IsUnset,

Optional (Some / Option setters).

pub fn region(self, value: String) -> CognitoEventBuilder<SetRegion<S>>
where S::Region: IsUnset,

Optional (Some / Option setters).

pub fn maybe_region( self, value: Option<String>, ) -> CognitoEventBuilder<SetRegion<S>>
where S::Region: IsUnset,

Optional (Some / Option setters).

pub fn version(self, value: i64) -> CognitoEventBuilder<SetVersion<S>>
where S::Version: IsUnset,

Required.

pub fn other( self, value: Map<String, Value>, ) -> CognitoEventBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> CognitoEventBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.