pub struct CognitoEventUserPoolsPreTokenGenRequestBuilder<S: State = Empty> { /* private fields */ }cognito only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CognitoEventUserPoolsPreTokenGenRequestBuilder<S>
impl<S: State> CognitoEventUserPoolsPreTokenGenRequestBuilder<S>
Sourcepub fn build(self) -> CognitoEventUserPoolsPreTokenGenRequestwhere
S: IsComplete,
pub fn build(self) -> CognitoEventUserPoolsPreTokenGenRequestwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn user_attributes(
self,
value: HashMap<String, String>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetUserAttributes<S>>where
S::UserAttributes: IsUnset,
pub fn user_attributes(
self,
value: HashMap<String, String>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetUserAttributes<S>>where
S::UserAttributes: IsUnset,
Required.
Sourcepub fn group_configuration(
self,
value: GroupConfiguration,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetGroupConfiguration<S>>where
S::GroupConfiguration: IsUnset,
pub fn group_configuration(
self,
value: GroupConfiguration,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetGroupConfiguration<S>>where
S::GroupConfiguration: IsUnset,
Required.
Group and role overrides. Note that null or missing values in the request
deserialize to GroupConfiguration::default.
Sourcepub fn client_metadata(
self,
value: HashMap<String, String>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetClientMetadata<S>>where
S::ClientMetadata: IsUnset,
pub fn client_metadata(
self,
value: HashMap<String, String>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetClientMetadata<S>>where
S::ClientMetadata: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CognitoEventUserPoolsPreTokenGenRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.