pub struct CognitoEventUserPoolsPreTokenGenV2Builder<S: State = Empty> { /* private fields */ }cognito only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CognitoEventUserPoolsPreTokenGenV2Builder<S>
impl<S: State> CognitoEventUserPoolsPreTokenGenV2Builder<S>
Sourcepub fn build(self) -> CognitoEventUserPoolsPreTokenGenV2where
S: IsComplete,
pub fn build(self) -> CognitoEventUserPoolsPreTokenGenV2where
S: IsComplete,
Finish building and return the requested object
Sourcepub fn cognito_event_user_pools_header(
self,
value: CognitoEventUserPoolsHeader<CognitoEventUserPoolsPreTokenGenTriggerSource>,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetCognitoEventUserPoolsHeader<S>>where
S::CognitoEventUserPoolsHeader: IsUnset,
pub fn cognito_event_user_pools_header(
self,
value: CognitoEventUserPoolsHeader<CognitoEventUserPoolsPreTokenGenTriggerSource>,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetCognitoEventUserPoolsHeader<S>>where
S::CognitoEventUserPoolsHeader: IsUnset,
Required.
Sourcepub fn request(
self,
value: CognitoEventUserPoolsPreTokenGenRequestV2,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetRequest<S>>where
S::Request: IsUnset,
pub fn request(
self,
value: CognitoEventUserPoolsPreTokenGenRequestV2,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetRequest<S>>where
S::Request: IsUnset,
Required.
Sourcepub fn response(
self,
value: CognitoEventUserPoolsPreTokenGenResponseV2,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetResponse<S>>where
S::Response: IsUnset,
pub fn response(
self,
value: CognitoEventUserPoolsPreTokenGenResponseV2,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetResponse<S>>where
S::Response: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CognitoEventUserPoolsPreTokenGenV2Builder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.