Module connect

Module connect 

Available on crate feature connect only.
AWS Lambda event definitions for connect.

Structs

ConnectContactData
ConnectContactData holds all of the contact information for the user that invoked the Connect event.
ConnectContactDataBuilder
Use builder syntax to set the inputs and finish with build().
ConnectDetails
ConnectDetails holds the details of a Connect event
ConnectDetailsBuilder
Use builder syntax to set the inputs and finish with build().
ConnectEndpoint
ConnectEndpoint represents routing information.
ConnectEndpointBuilder
Use builder syntax to set the inputs and finish with build().
ConnectEvent
ConnectEvent contains the data structure for a Connect event.
ConnectEventBuilder
Use builder syntax to set the inputs and finish with build().
ConnectQueue
ConnectQueue represents a queue object.
ConnectQueueBuilder
Use builder syntax to set the inputs and finish with build().

Type Aliases

ConnectResponse