#[non_exhaustive]pub struct ConnectDetails {
pub contact_data: ConnectContactData,
pub parameters: HashMap<String, String>,
pub other: Map<String, Value>,
}Available on crate feature
connect only.Expand description
ConnectDetails holds the details of a Connect event
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.contact_data: ConnectContactDataparameters: HashMap<String, String>The parameters that have been set in the Connect instance at the time of the Lambda invocation.
other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ConnectDetails
impl ConnectDetails
Sourcepub fn builder() -> ConnectDetailsBuilder
pub fn builder() -> ConnectDetailsBuilder
Create an instance of ConnectDetails using the builder syntax