pub struct ConnectEventBuilder<S: State = Empty> { /* private fields */ }connect only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ConnectEventBuilder<S>
impl<S: State> ConnectEventBuilder<S>
Sourcepub fn build(self) -> ConnectEventwhere
S: IsComplete,
pub fn build(self) -> ConnectEventwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn details(
self,
value: ConnectDetails,
) -> ConnectEventBuilder<SetDetails<S>>where
S::Details: IsUnset,
pub fn details(
self,
value: ConnectDetails,
) -> ConnectEventBuilder<SetDetails<S>>where
S::Details: IsUnset,
Required.
Sourcepub fn name(self, value: String) -> ConnectEventBuilder<SetName<S>>where
S::Name: IsUnset,
pub fn name(self, value: String) -> ConnectEventBuilder<SetName<S>>where
S::Name: IsUnset,
Sourcepub fn maybe_name(
self,
value: Option<String>,
) -> ConnectEventBuilder<SetName<S>>where
S::Name: IsUnset,
pub fn maybe_name(
self,
value: Option<String>,
) -> ConnectEventBuilder<SetName<S>>where
S::Name: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ConnectEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ConnectEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ConnectEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ConnectEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.