#[non_exhaustive]pub struct ConnectQueue {
pub name: Option<String>,
pub arn: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
connect only.Expand description
ConnectQueue represents a queue object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>arn: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl ConnectQueue
impl ConnectQueue
Sourcepub fn builder() -> ConnectQueueBuilder
pub fn builder() -> ConnectQueueBuilder
Create an instance of ConnectQueue using the builder syntax