pub struct ConnectQueueBuilder<S: State = Empty> { /* private fields */ }connect only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ConnectQueueBuilder<S>
impl<S: State> ConnectQueueBuilder<S>
Sourcepub fn build(self) -> ConnectQueuewhere
S: IsComplete,
pub fn build(self) -> ConnectQueuewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn name(self, value: String) -> ConnectQueueBuilder<SetName<S>>where
S::Name: IsUnset,
pub fn name(self, value: String) -> ConnectQueueBuilder<SetName<S>>where
S::Name: IsUnset,
Sourcepub fn maybe_name(
self,
value: Option<String>,
) -> ConnectQueueBuilder<SetName<S>>where
S::Name: IsUnset,
pub fn maybe_name(
self,
value: Option<String>,
) -> ConnectQueueBuilder<SetName<S>>where
S::Name: IsUnset,
Sourcepub fn arn(self, value: String) -> ConnectQueueBuilder<SetArn<S>>where
S::Arn: IsUnset,
pub fn arn(self, value: String) -> ConnectQueueBuilder<SetArn<S>>where
S::Arn: IsUnset,
Sourcepub fn maybe_arn(self, value: Option<String>) -> ConnectQueueBuilder<SetArn<S>>where
S::Arn: IsUnset,
pub fn maybe_arn(self, value: Option<String>) -> ConnectQueueBuilder<SetArn<S>>where
S::Arn: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ConnectQueueBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ConnectQueueBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ConnectQueueBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ConnectQueueBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.