ChangeDropEventBuilder

Struct ChangeDropEventBuilder 

pub struct ChangeDropEventBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature documentdb only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ChangeDropEventBuilder<S>

pub fn build(self) -> ChangeDropEvent
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: DocumentId) -> ChangeDropEventBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

pub fn cluster_time( self, value: Timestamp, ) -> ChangeDropEventBuilder<SetClusterTime<S>>
where S::ClusterTime: IsUnset,

Optional (Some / Option setters).

pub fn maybe_cluster_time( self, value: Option<Timestamp>, ) -> ChangeDropEventBuilder<SetClusterTime<S>>
where S::ClusterTime: IsUnset,

Optional (Some / Option setters).

pub fn ls_id(self, value: AnyDocument) -> ChangeDropEventBuilder<SetLsId<S>>
where S::LsId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_ls_id( self, value: Option<AnyDocument>, ) -> ChangeDropEventBuilder<SetLsId<S>>
where S::LsId: IsUnset,

Optional (Some / Option setters).

pub fn ns(self, value: DatabaseCollection) -> ChangeDropEventBuilder<SetNs<S>>
where S::Ns: IsUnset,

Required.

pub fn txn_number( self, value: String, ) -> ChangeDropEventBuilder<SetTxnNumber<S>>
where S::TxnNumber: IsUnset,

Optional (Some / Option setters).

pub fn maybe_txn_number( self, value: Option<String>, ) -> ChangeDropEventBuilder<SetTxnNumber<S>>
where S::TxnNumber: IsUnset,

Optional (Some / Option setters).

pub fn other( self, value: Map<String, Value>, ) -> ChangeDropEventBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> ChangeDropEventBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.