Module dynamodb

Module dynamodb 

Available on crate feature dynamodb only.
AWS Lambda event definitions for dynamodb.

Structs

Event
The Event stream event handled to Lambda http://docs.aws.amazon.com/lambda/latest/dg/eventsources.html#eventsources-ddb-update
EventBuilder
Use builder syntax to set the inputs and finish with build().
EventRecord
EventRecord stores information about each record of a DynamoDb stream event
EventRecordBuilder
Use builder syntax to set the inputs and finish with build().
StreamRecord
DynamoDbStreamRecord represents a description of a single data modification that was performed on an item in a DynamoDB table.
StreamRecordBuilder
Use builder syntax to set the inputs and finish with build().
TimeWindowEvent
TimeWindowEvent represents an Amazon Dynamodb event when using time windows ref. https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-windows
TimeWindowEventBuilder
Use builder syntax to set the inputs and finish with build().
TimeWindowEventResponse
TimeWindowEventResponse is the outer structure to report batch item failures for DynamoDBTimeWindowEvent.
TimeWindowEventResponseBuilder
Use builder syntax to set the inputs and finish with build().
UserIdentity
UserIdentityBuilder
Use builder syntax to set the inputs and finish with build().

Enums

KeyType
OperationType
SharedIteratorType
StreamStatus
StreamViewType