EventRecordBuilder

Struct EventRecordBuilder 

pub struct EventRecordBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature dynamodb only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> EventRecordBuilder<S>

pub fn build(self) -> EventRecord
where S: IsComplete,

Finish building and return the requested object

pub fn aws_region(self, value: String) -> EventRecordBuilder<SetAwsRegion<S>>
where S::AwsRegion: IsUnset,

Required.

The region in which the GetRecords request was received.

pub fn change(self, value: StreamRecord) -> EventRecordBuilder<SetChange<S>>
where S::Change: IsUnset,

Required.

The main body of the stream record, containing all of the DynamoDB-specific fields.

pub fn event_id(self, value: String) -> EventRecordBuilder<SetEventId<S>>
where S::EventId: IsUnset,

Required.

A globally unique identifier for the event that was recorded in this stream record.

pub fn event_name(self, value: String) -> EventRecordBuilder<SetEventName<S>>
where S::EventName: IsUnset,

Required.

The type of data modification that was performed on the DynamoDB table:

  • INSERT - a new item was added to the table.

  • MODIFY - one or more of an existing item’s attributes were modified.

  • REMOVE - the item was deleted from the table

pub fn event_source( self, value: String, ) -> EventRecordBuilder<SetEventSource<S>>
where S::EventSource: IsUnset,

Optional (Some / Option setters). The AWS service from which the stream record originated. For DynamoDB Streams, this is aws:dynamodb.

pub fn maybe_event_source( self, value: Option<String>, ) -> EventRecordBuilder<SetEventSource<S>>
where S::EventSource: IsUnset,

Optional (Some / Option setters). The AWS service from which the stream record originated. For DynamoDB Streams, this is aws:dynamodb.

pub fn event_version( self, value: String, ) -> EventRecordBuilder<SetEventVersion<S>>
where S::EventVersion: IsUnset,

Optional (Some / Option setters). The version number of the stream record format. This number is updated whenever the structure of Record is modified.

Client applications must not assume that eventVersion will remain at a particular value, as this number is subject to change at any time. In general, eventVersion will only increase as the low-level DynamoDB Streams API evolves.

pub fn maybe_event_version( self, value: Option<String>, ) -> EventRecordBuilder<SetEventVersion<S>>
where S::EventVersion: IsUnset,

Optional (Some / Option setters). The version number of the stream record format. This number is updated whenever the structure of Record is modified.

Client applications must not assume that eventVersion will remain at a particular value, as this number is subject to change at any time. In general, eventVersion will only increase as the low-level DynamoDB Streams API evolves.

pub fn event_source_arn( self, value: String, ) -> EventRecordBuilder<SetEventSourceArn<S>>
where S::EventSourceArn: IsUnset,

Optional (Some / Option setters). The event source ARN of DynamoDB

pub fn maybe_event_source_arn( self, value: Option<String>, ) -> EventRecordBuilder<SetEventSourceArn<S>>
where S::EventSourceArn: IsUnset,

Optional (Some / Option setters). The event source ARN of DynamoDB

pub fn user_identity( self, value: UserIdentity, ) -> EventRecordBuilder<SetUserIdentity<S>>
where S::UserIdentity: IsUnset,

Optional (Some / Option setters). Items that are deleted by the Time to Live process after expiration have the following fields:

  • Records[].userIdentity.type

“Service”

  • Records[].userIdentity.principalId

“dynamodb.amazonaws.com”

pub fn maybe_user_identity( self, value: Option<UserIdentity>, ) -> EventRecordBuilder<SetUserIdentity<S>>
where S::UserIdentity: IsUnset,

Optional (Some / Option setters). Items that are deleted by the Time to Live process after expiration have the following fields:

  • Records[].userIdentity.type

“Service”

  • Records[].userIdentity.principalId

“dynamodb.amazonaws.com”

pub fn record_format( self, value: String, ) -> EventRecordBuilder<SetRecordFormat<S>>
where S::RecordFormat: IsUnset,

Optional (Some / Option setters). Describes the record format and relevant mapping information that should be applied to schematize the records on the stream. For DynamoDB Streams, this is application/json.

pub fn maybe_record_format( self, value: Option<String>, ) -> EventRecordBuilder<SetRecordFormat<S>>
where S::RecordFormat: IsUnset,

Optional (Some / Option setters). Describes the record format and relevant mapping information that should be applied to schematize the records on the stream. For DynamoDB Streams, this is application/json.

pub fn table_name(self, value: String) -> EventRecordBuilder<SetTableName<S>>
where S::TableName: IsUnset,

Optional (Some / Option setters). The DynamoDB table that this event was recorded for.

pub fn maybe_table_name( self, value: Option<String>, ) -> EventRecordBuilder<SetTableName<S>>
where S::TableName: IsUnset,

Optional (Some / Option setters). The DynamoDB table that this event was recorded for.

pub fn other(self, value: Map<String, Value>) -> EventRecordBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> EventRecordBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.