StreamRecord

Struct StreamRecord 

#[non_exhaustive]
pub struct StreamRecord { pub approximate_creation_date_time: DateTime<Utc>, pub keys: Item, pub new_image: Item, pub old_image: Item, pub sequence_number: Option<String>, pub size_bytes: i64, pub stream_view_type: Option<StreamViewType>, pub other: Map<String, Value>, }
Available on crate feature dynamodb only.
DynamoDbStreamRecord represents a description of a single data modification that was performed on an item in a DynamoDB table.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
approximate_creation_date_time: DateTime<Utc>

The approximate date and time when the stream record was created, in UNIX epoch time (http://www.epochconverter.com/) format. Might not be present in the record: https://github.com/aws/aws-lambda-rust-runtime/issues/889

keys: Item

The primary key attribute(s) for the DynamoDB item that was modified.

new_image: Item

The item in the DynamoDB table as it appeared after it was modified.

old_image: Item

The item in the DynamoDB table as it appeared before it was modified.

sequence_number: Option<String>

The sequence number of the stream record.

size_bytes: i64

The size of the stream record, in bytes.

stream_view_type: Option<StreamViewType>

The type of data from the modified DynamoDB item that was captured in this stream record.

other: Map<String, Value>
Available on crate feature catch-all-fields only.

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

Implementations

Source

impl StreamRecord

pub fn builder() -> StreamRecordBuilder

Create an instance of StreamRecord using the builder syntax