#[non_exhaustive]pub struct TimeWindowEventResponse {
pub time_window_event_response_properties: TimeWindowEventResponseProperties,
pub batch_item_failures: Vec<DynamoDbBatchItemFailure>,
pub other: Map<String, Value>,
}Available on crate feature
dynamodb only.Expand description
TimeWindowEventResponse is the outer structure to report batch item failures for DynamoDBTimeWindowEvent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time_window_event_response_properties: TimeWindowEventResponsePropertiesbatch_item_failures: Vec<DynamoDbBatchItemFailure>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.