Module ecr_scan

Module ecr_scan 

Available on crate feature ecr_scan only.
AWS Lambda event definitions for ecr_scan.

Structs

EcrScanEvent
EcrScanEventBuilder
Use builder syntax to set the inputs and finish with build().
EcrScanEventDetailType
EcrScanEventDetailTypeBuilder
Use builder syntax to set the inputs and finish with build().
EcrScanEventFindingSeverityCounts
EcrScanEventFindingSeverityCountsBuilder
Use builder syntax to set the inputs and finish with build().