EventBridgeEvent

Struct EventBridgeEvent 

#[non_exhaustive]
pub struct EventBridgeEvent<T1 = Value>{ pub version: Option<String>, pub id: Option<String>, pub detail_type: String, pub source: String, pub account: Option<String>, pub time: Option<DateTime<Utc>>, pub region: Option<String>, pub resources: Option<Vec<String>>, pub detail: T1, pub other: Map<String, Value>, }
Available on crate feature eventbridge only.
Parse EventBridge events. Deserialize the event detail into a structure that’s DeserializeOwned.

See https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-events-structure.html for structure details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
version: Option<String>id: Option<String>detail_type: Stringsource: Stringaccount: Option<String>time: Option<DateTime<Utc>>region: Option<String>resources: Option<Vec<String>>detail: T1other: Map<String, Value>
Available on crate feature catch-all-fields only.

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

Implementations

Source

impl<T1> EventBridgeEvent<T1>

pub fn builder() -> EventBridgeEventBuilder<T1>

Create an instance of EventBridgeEvent using the builder syntax