#[non_exhaustive]pub struct IoTCoreHttpContext {
pub headers: HeaderMap,
pub query_string: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
iot only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.headers: HeaderMapquery_string: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl IoTCoreHttpContext
impl IoTCoreHttpContext
Sourcepub fn builder() -> IoTCoreHttpContextBuilder
pub fn builder() -> IoTCoreHttpContextBuilder
Create an instance of IoTCoreHttpContext using the builder syntax