Module iot_1_click

Module iot_1_click 

Available on crate feature iot_1_click only.
AWS Lambda event definitions for iot_1_click.

Structs

IoTOneClickButtonClicked
IoTOneClickButtonClickedBuilder
Use builder syntax to set the inputs and finish with build().
IoTOneClickDeviceEvent
IoTOneClickDeviceEventBuilder
Use builder syntax to set the inputs and finish with build().
IoTOneClickDeviceInfo
IoTOneClickDeviceInfoBuilder
Use builder syntax to set the inputs and finish with build().
IoTOneClickEvent
IoTOneClickEvent represents a click event published by clicking button type device.
IoTOneClickEventBuilder
Use builder syntax to set the inputs and finish with build().
IoTOneClickPlacementInfo
IoTOneClickPlacementInfoBuilder
Use builder syntax to set the inputs and finish with build().