pub struct IoTOneClickButtonClickedBuilder<S: State = Empty> { /* private fields */ }iot_1_click only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> IoTOneClickButtonClickedBuilder<S>
impl<S: State> IoTOneClickButtonClickedBuilder<S>
Sourcepub fn build(self) -> IoTOneClickButtonClickedwhere
S: IsComplete,
pub fn build(self) -> IoTOneClickButtonClickedwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn click_type(
self,
value: String,
) -> IoTOneClickButtonClickedBuilder<SetClickType<S>>where
S::ClickType: IsUnset,
pub fn click_type(
self,
value: String,
) -> IoTOneClickButtonClickedBuilder<SetClickType<S>>where
S::ClickType: IsUnset,
Sourcepub fn maybe_click_type(
self,
value: Option<String>,
) -> IoTOneClickButtonClickedBuilder<SetClickType<S>>where
S::ClickType: IsUnset,
pub fn maybe_click_type(
self,
value: Option<String>,
) -> IoTOneClickButtonClickedBuilder<SetClickType<S>>where
S::ClickType: IsUnset,
Sourcepub fn reported_time(
self,
value: String,
) -> IoTOneClickButtonClickedBuilder<SetReportedTime<S>>where
S::ReportedTime: IsUnset,
pub fn reported_time(
self,
value: String,
) -> IoTOneClickButtonClickedBuilder<SetReportedTime<S>>where
S::ReportedTime: IsUnset,
Sourcepub fn maybe_reported_time(
self,
value: Option<String>,
) -> IoTOneClickButtonClickedBuilder<SetReportedTime<S>>where
S::ReportedTime: IsUnset,
pub fn maybe_reported_time(
self,
value: Option<String>,
) -> IoTOneClickButtonClickedBuilder<SetReportedTime<S>>where
S::ReportedTime: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> IoTOneClickButtonClickedBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> IoTOneClickButtonClickedBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> IoTOneClickButtonClickedBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> IoTOneClickButtonClickedBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.