pub struct IoTOneClickDeviceEventBuilder<S: State = Empty> { /* private fields */ }iot_1_click only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> IoTOneClickDeviceEventBuilder<S>
impl<S: State> IoTOneClickDeviceEventBuilder<S>
Sourcepub fn build(self) -> IoTOneClickDeviceEventwhere
S: IsComplete,
pub fn build(self) -> IoTOneClickDeviceEventwhere
S: IsComplete,
Finish building and return the requested object
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> IoTOneClickDeviceEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> IoTOneClickDeviceEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> IoTOneClickDeviceEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> IoTOneClickDeviceEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.