pub struct IoTOneClickDeviceInfoBuilder<S: State = Empty> { /* private fields */ }iot_1_click only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> IoTOneClickDeviceInfoBuilder<S>
impl<S: State> IoTOneClickDeviceInfoBuilder<S>
Sourcepub fn build(self) -> IoTOneClickDeviceInfowhere
S: IsComplete,
pub fn build(self) -> IoTOneClickDeviceInfowhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn attributes(
self,
value: HashMap<String, String>,
) -> IoTOneClickDeviceInfoBuilder<SetAttributes<S>>where
S::Attributes: IsUnset,
pub fn attributes(
self,
value: HashMap<String, String>,
) -> IoTOneClickDeviceInfoBuilder<SetAttributes<S>>where
S::Attributes: IsUnset,
Required.
Sourcepub fn type_(self, value: String) -> IoTOneClickDeviceInfoBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn type_(self, value: String) -> IoTOneClickDeviceInfoBuilder<SetType<S>>where
S::Type: IsUnset,
Sourcepub fn maybe_type_(
self,
value: Option<String>,
) -> IoTOneClickDeviceInfoBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn maybe_type_(
self,
value: Option<String>,
) -> IoTOneClickDeviceInfoBuilder<SetType<S>>where
S::Type: IsUnset,
Sourcepub fn device_id(
self,
value: String,
) -> IoTOneClickDeviceInfoBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
pub fn device_id(
self,
value: String,
) -> IoTOneClickDeviceInfoBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
Sourcepub fn maybe_device_id(
self,
value: Option<String>,
) -> IoTOneClickDeviceInfoBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
pub fn maybe_device_id(
self,
value: Option<String>,
) -> IoTOneClickDeviceInfoBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
Sourcepub fn remaining_life(
self,
value: f64,
) -> IoTOneClickDeviceInfoBuilder<SetRemainingLife<S>>where
S::RemainingLife: IsUnset,
pub fn remaining_life(
self,
value: f64,
) -> IoTOneClickDeviceInfoBuilder<SetRemainingLife<S>>where
S::RemainingLife: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> IoTOneClickDeviceInfoBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> IoTOneClickDeviceInfoBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> IoTOneClickDeviceInfoBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> IoTOneClickDeviceInfoBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.