#[non_exhaustive]pub struct IoTOneClickPlacementInfo {
pub project_name: Option<String>,
pub placement_name: Option<String>,
pub attributes: HashMap<String, String>,
pub devices: HashMap<String, String>,
pub other: Map<String, Value>,
}Available on crate feature
iot_1_click only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_name: Option<String>placement_name: Option<String>attributes: HashMap<String, String>devices: HashMap<String, String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl IoTOneClickPlacementInfo
impl IoTOneClickPlacementInfo
Sourcepub fn builder() -> IoTOneClickPlacementInfoBuilder
pub fn builder() -> IoTOneClickPlacementInfoBuilder
Create an instance of IoTOneClickPlacementInfo using the builder syntax