Module iot_deprecated

Module iot_deprecated 

Available on crate feature iot_deprecated only.
AWS Lambda event definitions for iot_deprecated.

Structs

IoTCustomAuthorizerRequest
IoTCustomAuthorizerRequest contains data coming in to a custom IoT device gateway authorizer function. Deprecated: Use IoTCoreCustomAuthorizerRequest instead. IoTCustomAuthorizerRequest does not correctly model the request schema
IoTCustomAuthorizerRequestBuilder
Use builder syntax to set the inputs and finish with build().
IoTCustomAuthorizerResponse
IoTCustomAuthorizerResponse represents the expected format of an IoT device gateway authorization response. Deprecated: Use IoTCoreCustomAuthorizerResponse. IoTCustomAuthorizerResponse does not correctly model the response schema.
IoTCustomAuthorizerResponseBuilder
Use builder syntax to set the inputs and finish with build().

Type Aliases

IoTHttpContext
IoTMqttContext
IoTTlsContext