Module kinesis

Module kinesis 

Available on crate feature kinesis only.
AWS Lambda event definitions for kinesis.

Modules

analytics

Structs

KinesisEvent
KinesisEventBuilder
Use builder syntax to set the inputs and finish with build().
KinesisEventRecord
KinesisEventRecordBuilder
Use builder syntax to set the inputs and finish with build().
KinesisRecord
KinesisRecordBuilder
Use builder syntax to set the inputs and finish with build().
KinesisTimeWindowEvent
KinesisTimeWindowEvent represents an Amazon Dynamodb event when using time windows ref. https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-windows
KinesisTimeWindowEventBuilder
Use builder syntax to set the inputs and finish with build().
KinesisTimeWindowEventResponse
KinesisTimeWindowEventResponse is the outer structure to report batch item failures for KinesisTimeWindowEvent.
KinesisTimeWindowEventResponseBuilder
Use builder syntax to set the inputs and finish with build().

Enums

KinesisEncryptionType