Available on crate feature
lambda_function_urls only.Expand description
AWS Lambda event definitions for lambda_function_urls.
Structs
- Lambda
Function UrlRequest LambdaFunctionUrlRequestcontains data coming from the HTTP request to a Lambda Function URL.- Lambda
Function UrlRequest Builder - Use builder syntax to set the inputs and finish with
build(). - Lambda
Function UrlRequest Context LambdaFunctionUrlRequestContextcontains the information to identify the AWS account and resources invoking the Lambda function.- Lambda
Function UrlRequest Context Authorizer Description LambdaFunctionUrlRequestContextAuthorizerDescriptioncontains authorizer information for the request context.- Lambda
Function UrlRequest Context Authorizer Description Builder - Use builder syntax to set the inputs and finish with
build(). - Lambda
Function UrlRequest Context Authorizer IamDescription LambdaFunctionUrlRequestContextAuthorizerIamDescriptioncontains IAM information for the request context.- Lambda
Function UrlRequest Context Authorizer IamDescription Builder - Use builder syntax to set the inputs and finish with
build(). - Lambda
Function UrlRequest Context Builder - Use builder syntax to set the inputs and finish with
build(). - Lambda
Function UrlRequest Context Http Description LambdaFunctionUrlRequestContextHttpDescriptioncontains HTTP information for the request context.- Lambda
Function UrlRequest Context Http Description Builder - Use builder syntax to set the inputs and finish with
build(). - Lambda
Function UrlResponse LambdaFunctionUrlResponseconfigures the HTTP response to be returned by Lambda Function URL for the request.- Lambda
Function UrlResponse Builder - Use builder syntax to set the inputs and finish with
build().