#[non_exhaustive]pub struct LambdaFunctionUrlRequest {
pub version: Option<String>,
pub raw_path: Option<String>,
pub raw_query_string: Option<String>,
pub cookies: Option<Vec<String>>,
pub headers: HeaderMap,
pub query_string_parameters: HashMap<String, String>,
pub request_context: LambdaFunctionUrlRequestContext,
pub body: Option<String>,
pub is_base64_encoded: bool,
pub other: Map<String, Value>,
}Available on crate feature
lambda_function_urls only.Expand description
LambdaFunctionUrlRequest contains data coming from the HTTP request to a Lambda Function URL.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.version: Option<String>Version is expected to be "2.0"
raw_path: Option<String>raw_query_string: Option<String>headers: HeaderMapquery_string_parameters: HashMap<String, String>request_context: LambdaFunctionUrlRequestContextbody: Option<String>is_base64_encoded: boolother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl LambdaFunctionUrlRequest
impl LambdaFunctionUrlRequest
Sourcepub fn builder() -> LambdaFunctionUrlRequestBuilder
pub fn builder() -> LambdaFunctionUrlRequestBuilder
Create an instance of LambdaFunctionUrlRequest using the builder syntax