LambdaFunctionUrlRequestBuilder

Struct LambdaFunctionUrlRequestBuilder 

pub struct LambdaFunctionUrlRequestBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature lambda_function_urls only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> LambdaFunctionUrlRequestBuilder<S>

pub fn build(self) -> LambdaFunctionUrlRequest
where S: IsComplete,

Finish building and return the requested object

pub fn version( self, value: String, ) -> LambdaFunctionUrlRequestBuilder<SetVersion<S>>
where S::Version: IsUnset,

Optional (Some / Option setters). Version is expected to be "2.0"

pub fn maybe_version( self, value: Option<String>, ) -> LambdaFunctionUrlRequestBuilder<SetVersion<S>>
where S::Version: IsUnset,

Optional (Some / Option setters). Version is expected to be "2.0"

pub fn raw_path( self, value: String, ) -> LambdaFunctionUrlRequestBuilder<SetRawPath<S>>
where S::RawPath: IsUnset,

Optional (Some / Option setters).

pub fn maybe_raw_path( self, value: Option<String>, ) -> LambdaFunctionUrlRequestBuilder<SetRawPath<S>>
where S::RawPath: IsUnset,

Optional (Some / Option setters).

pub fn raw_query_string( self, value: String, ) -> LambdaFunctionUrlRequestBuilder<SetRawQueryString<S>>
where S::RawQueryString: IsUnset,

Optional (Some / Option setters).

pub fn maybe_raw_query_string( self, value: Option<String>, ) -> LambdaFunctionUrlRequestBuilder<SetRawQueryString<S>>
where S::RawQueryString: IsUnset,

Optional (Some / Option setters).

pub fn cookies( self, value: Vec<String>, ) -> LambdaFunctionUrlRequestBuilder<SetCookies<S>>
where S::Cookies: IsUnset,

Optional (Some / Option setters).

pub fn maybe_cookies( self, value: Option<Vec<String>>, ) -> LambdaFunctionUrlRequestBuilder<SetCookies<S>>
where S::Cookies: IsUnset,

Optional (Some / Option setters).

pub fn headers( self, value: HeaderMap, ) -> LambdaFunctionUrlRequestBuilder<SetHeaders<S>>
where S::Headers: IsUnset,

Required.

pub fn query_string_parameters( self, value: HashMap<String, String>, ) -> LambdaFunctionUrlRequestBuilder<SetQueryStringParameters<S>>
where S::QueryStringParameters: IsUnset,

Required.

pub fn request_context( self, value: LambdaFunctionUrlRequestContext, ) -> LambdaFunctionUrlRequestBuilder<SetRequestContext<S>>
where S::RequestContext: IsUnset,

Required.

pub fn body(self, value: String) -> LambdaFunctionUrlRequestBuilder<SetBody<S>>
where S::Body: IsUnset,

Optional (Some / Option setters).

pub fn maybe_body( self, value: Option<String>, ) -> LambdaFunctionUrlRequestBuilder<SetBody<S>>
where S::Body: IsUnset,

Optional (Some / Option setters).

pub fn is_base64_encoded( self, value: bool, ) -> LambdaFunctionUrlRequestBuilder<SetIsBase64Encoded<S>>
where S::IsBase64Encoded: IsUnset,

Required.

pub fn other( self, value: Map<String, Value>, ) -> LambdaFunctionUrlRequestBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> LambdaFunctionUrlRequestBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.