Module s3

Module s3 

Available on crate feature s3 only.
AWS Lambda event definitions for s3.

Modules

batch_job
object_lambda

Structs

S3Bucket
S3BucketBuilder
Use builder syntax to set the inputs and finish with build().
S3Entity
S3EntityBuilder
Use builder syntax to set the inputs and finish with build().
S3Event
S3Event which wrap an array of S3EventRecord
S3EventBuilder
Use builder syntax to set the inputs and finish with build().
S3EventRecord
S3EventRecord which wrap record data
S3EventRecordBuilder
Use builder syntax to set the inputs and finish with build().
S3Object
S3ObjectBuilder
Use builder syntax to set the inputs and finish with build().
S3RequestParameters
S3RequestParametersBuilder
Use builder syntax to set the inputs and finish with build().
S3UserIdentity
S3UserIdentityBuilder
Use builder syntax to set the inputs and finish with build().