Module batch_job

Module batch_job 

Available on crate feature s3 only.

Structs

S3BatchJob
S3BatchJob whichs have the job id
S3BatchJobBuilder
Use builder syntax to set the inputs and finish with build().
S3BatchJobEvent
S3BatchJobEvent encapsulates the detail of a s3 batch job
S3BatchJobEventBuilder
Use builder syntax to set the inputs and finish with build().
S3BatchJobResponse
S3BatchJobResponse is the response of a iven s3 batch job with the results
S3BatchJobResponseBuilder
Use builder syntax to set the inputs and finish with build().
S3BatchJobResult
S3BatchJobResult represents the result of a given task
S3BatchJobResultBuilder
Use builder syntax to set the inputs and finish with build().
S3BatchJobTask
S3BatchJobTask represents one task in the s3 batch job and have all task details
S3BatchJobTaskBuilder
Use builder syntax to set the inputs and finish with build().