#[non_exhaustive]pub struct S3BatchJobResult {
pub task_id: Option<String>,
pub result_code: Option<String>,
pub result_string: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
s3 only.Expand description
S3BatchJobResult represents the result of a given task
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_id: Option<String>result_code: Option<String>result_string: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl S3BatchJobResult
impl S3BatchJobResult
Sourcepub fn builder() -> S3BatchJobResultBuilder
pub fn builder() -> S3BatchJobResultBuilder
Create an instance of S3BatchJobResult using the builder syntax