Module object_lambda

Module object_lambda 

Available on crate feature s3 only.

Structs

Configuration
Configuration contains information about the Object Lambda access point
ConfigurationBuilder
Use builder syntax to set the inputs and finish with build().
GetObjectContext
GetObjectContext contains the input and output details for connections to Amazon S3 and S3 Object Lambda
GetObjectContextBuilder
Use builder syntax to set the inputs and finish with build().
HeadObjectContext
HeadObjectContext for connections to Amazon S3 and S3 Object Lambda
HeadObjectContextBuilder
Use builder syntax to set the inputs and finish with build().
ListObjectsContext
ListObjectsContext for connections to Amazon S3 and S3 Object Lambda
ListObjectsContextBuilder
Use builder syntax to set the inputs and finish with build().
ListObjectsV2Context
ListObjectsV2Context for connections to Amazon S3 and S3 Object Lambda
ListObjectsV2ContextBuilder
Use builder syntax to set the inputs and finish with build().
S3ObjectLambdaEvent
S3ObjectLambdaEvent contains data coming from S3 object lambdas See: https://docs.aws.amazon.com/AmazonS3/latest/userguide/olap-writing-lambda.html
S3ObjectLambdaEventBuilder
Use builder syntax to set the inputs and finish with build().
SessionContext
SessionContextBuilder
Use builder syntax to set the inputs and finish with build().
SessionIssuer
SessionIssuerBuilder
Use builder syntax to set the inputs and finish with build().
UserIdentity
UserIdentity contains details about the identity that made the call to S3 Object Lambda
UserIdentityBuilder
Use builder syntax to set the inputs and finish with build().
UserRequest
UserRequest contains information about the original call to S3 Object Lambda
UserRequestBuilder
Use builder syntax to set the inputs and finish with build().