pub struct ListObjectsV2ContextBuilder<S: State = Empty> { /* private fields */ }s3 only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ListObjectsV2ContextBuilder<S>
impl<S: State> ListObjectsV2ContextBuilder<S>
Sourcepub fn build(self) -> ListObjectsV2Contextwhere
S: IsComplete,
pub fn build(self) -> ListObjectsV2Contextwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn input_s3_url(
self,
value: String,
) -> ListObjectsV2ContextBuilder<SetInputS3Url<S>>where
S::InputS3Url: IsUnset,
pub fn input_s3_url(
self,
value: String,
) -> ListObjectsV2ContextBuilder<SetInputS3Url<S>>where
S::InputS3Url: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ListObjectsV2ContextBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ListObjectsV2ContextBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ListObjectsV2ContextBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ListObjectsV2ContextBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.