pub struct S3EventBuilder<S: State = Empty> { /* private fields */ }s3 only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> S3EventBuilder<S>
impl<S: State> S3EventBuilder<S>
Sourcepub fn build(self) -> S3Eventwhere
S: IsComplete,
pub fn build(self) -> S3Eventwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn records(self, value: Vec<S3EventRecord>) -> S3EventBuilder<SetRecords<S>>where
S::Records: IsUnset,
pub fn records(self, value: Vec<S3EventRecord>) -> S3EventBuilder<SetRecords<S>>where
S::Records: IsUnset,
Required.
Sourcepub fn other(self, value: Map<String, Value>) -> S3EventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(self, value: Map<String, Value>) -> S3EventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> S3EventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> S3EventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.