#[non_exhaustive]pub struct SimpleEmailMessage {
pub common_headers: SimpleEmailCommonHeaders,
pub source: Option<String>,
pub timestamp: DateTime<Utc>,
pub destination: Vec<String>,
pub headers: Vec<SimpleEmailHeader>,
pub headers_truncated: bool,
pub message_id: Option<String>,
pub other: Map<String, Value>,
}Available on crate feature
ses only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.common_headers: SimpleEmailCommonHeaderssource: Option<String>timestamp: DateTime<Utc>destination: Vec<String>headers: Vec<SimpleEmailHeader>headers_truncated: boolmessage_id: Option<String>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl SimpleEmailMessage
impl SimpleEmailMessage
Sourcepub fn builder() -> SimpleEmailMessageBuilder
pub fn builder() -> SimpleEmailMessageBuilder
Create an instance of SimpleEmailMessage using the builder syntax