#[non_exhaustive]pub struct SimpleEmailRecord {
pub event_version: Option<String>,
pub event_source: Option<String>,
pub ses: SimpleEmailService,
pub other: Map<String, Value>,
}Available on crate feature
ses only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_version: Option<String>event_source: Option<String>ses: SimpleEmailServiceother: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl SimpleEmailRecord
impl SimpleEmailRecord
Sourcepub fn builder() -> SimpleEmailRecordBuilder
pub fn builder() -> SimpleEmailRecordBuilder
Create an instance of SimpleEmailRecord using the builder syntax