pub struct CloudWatchMetricBuilder<S: State = Empty> { /* private fields */ }sns only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CloudWatchMetricBuilder<S>
impl<S: State> CloudWatchMetricBuilder<S>
Sourcepub fn build(self) -> CloudWatchMetricwhere
S: IsComplete,
pub fn build(self) -> CloudWatchMetricwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn dimensions(
self,
value: Vec<CloudWatchDimension>,
) -> CloudWatchMetricBuilder<SetDimensions<S>>where
S::Dimensions: IsUnset,
pub fn dimensions(
self,
value: Vec<CloudWatchDimension>,
) -> CloudWatchMetricBuilder<SetDimensions<S>>where
S::Dimensions: IsUnset,
Required.
Sourcepub fn metric_name(
self,
value: String,
) -> CloudWatchMetricBuilder<SetMetricName<S>>where
S::MetricName: IsUnset,
pub fn metric_name(
self,
value: String,
) -> CloudWatchMetricBuilder<SetMetricName<S>>where
S::MetricName: IsUnset,
Sourcepub fn maybe_metric_name(
self,
value: Option<String>,
) -> CloudWatchMetricBuilder<SetMetricName<S>>where
S::MetricName: IsUnset,
pub fn maybe_metric_name(
self,
value: Option<String>,
) -> CloudWatchMetricBuilder<SetMetricName<S>>where
S::MetricName: IsUnset,
Sourcepub fn namespace(
self,
value: String,
) -> CloudWatchMetricBuilder<SetNamespace<S>>where
S::Namespace: IsUnset,
pub fn namespace(
self,
value: String,
) -> CloudWatchMetricBuilder<SetNamespace<S>>where
S::Namespace: IsUnset,
Sourcepub fn maybe_namespace(
self,
value: Option<String>,
) -> CloudWatchMetricBuilder<SetNamespace<S>>where
S::Namespace: IsUnset,
pub fn maybe_namespace(
self,
value: Option<String>,
) -> CloudWatchMetricBuilder<SetNamespace<S>>where
S::Namespace: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CloudWatchMetricBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CloudWatchMetricBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CloudWatchMetricBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CloudWatchMetricBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.