#[non_exhaustive]pub struct SqsApiMessage {
pub message_id: Option<String>,
pub receipt_handle: Option<String>,
pub body: Option<String>,
pub md5_of_body: Option<String>,
pub md5_of_message_attributes: Option<String>,
pub attributes: HashMap<String, String>,
pub message_attributes: HashMap<String, SqsMessageAttribute>,
pub other: Map<String, Value>,
}Available on crate feature
sqs only.Expand description
An individual SQS API Message, its metadata, and Message Attributes
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_id: Option<String>nolint: stylecheck
receipt_handle: Option<String>body: Option<String>md5_of_body: Option<String>md5_of_message_attributes: Option<String>attributes: HashMap<String, String>message_attributes: HashMap<String, SqsMessageAttribute>other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Implementations
Sourceimpl SqsApiMessage
impl SqsApiMessage
Sourcepub fn builder() -> SqsApiMessageBuilder
pub fn builder() -> SqsApiMessageBuilder
Create an instance of SqsApiMessage using the builder syntax