SqsMessageAttributeBuilder

Struct SqsMessageAttributeBuilder 

pub struct SqsMessageAttributeBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature sqs only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> SqsMessageAttributeBuilder<S>

pub fn build(self) -> SqsMessageAttribute
where S: IsComplete,

Finish building and return the requested object

pub fn string_value( self, value: String, ) -> SqsMessageAttributeBuilder<SetStringValue<S>>
where S::StringValue: IsUnset,

Optional (Some / Option setters).

pub fn maybe_string_value( self, value: Option<String>, ) -> SqsMessageAttributeBuilder<SetStringValue<S>>
where S::StringValue: IsUnset,

Optional (Some / Option setters).

pub fn binary_value( self, value: Base64Data, ) -> SqsMessageAttributeBuilder<SetBinaryValue<S>>
where S::BinaryValue: IsUnset,

Optional (Some / Option setters).

pub fn maybe_binary_value( self, value: Option<Base64Data>, ) -> SqsMessageAttributeBuilder<SetBinaryValue<S>>
where S::BinaryValue: IsUnset,

Optional (Some / Option setters).

pub fn string_list_values( self, value: Vec<String>, ) -> SqsMessageAttributeBuilder<SetStringListValues<S>>
where S::StringListValues: IsUnset,

Required.

pub fn binary_list_values( self, value: Vec<Base64Data>, ) -> SqsMessageAttributeBuilder<SetBinaryListValues<S>>
where S::BinaryListValues: IsUnset,

Required.

pub fn data_type( self, value: String, ) -> SqsMessageAttributeBuilder<SetDataType<S>>
where S::DataType: IsUnset,

Optional (Some / Option setters).

pub fn maybe_data_type( self, value: Option<String>, ) -> SqsMessageAttributeBuilder<SetDataType<S>>
where S::DataType: IsUnset,

Optional (Some / Option setters).

pub fn other( self, value: Map<String, Value>, ) -> SqsMessageAttributeBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.

pub fn maybe_other( self, value: Option<Map<String, Value>>, ) -> SqsMessageAttributeBuilder<SetOther<S>>
where S::Other: IsUnset,

Optional (Some / Option setters). Default: <serde_json::Map<String, Value> as Default>::default().

Catchall to catch any additional fields that were present but not explicitly defined by this struct. Enabled with Cargo feature catch-all-fields. If catch-all-fields is disabled, any additional fields that are present will be ignored.