#[non_exhaustive]pub struct VpcLatticeRequestV2Context {
pub service_network_arn: String,
pub service_arn: String,
pub target_group_arn: String,
pub identity: Option<VpcLatticeRequestV2Identity>,
pub region: String,
pub time_epoch: String,
pub other: Map<String, Value>,
}Available on crate feature
vpc_lattice only.Expand description
VPC Lattice specific request context
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_network_arn: StringARN of the service network that delivers the request
service_arn: StringARN of the service that receives the request
target_group_arn: StringARN of the target group that receives the request
identity: Option<VpcLatticeRequestV2Identity>Identity information for the request. Present only if authentication is configured.
region: StringAWS region where the request is processed
time_epoch: StringTime of the request in microseconds since epoch
other: Map<String, Value>Available on crate feature
catch-all-fields only.Catchall for additional context fields
Implementations
Sourceimpl VpcLatticeRequestV2Context
impl VpcLatticeRequestV2Context
Sourcepub fn builder() -> VpcLatticeRequestV2ContextBuilder
pub fn builder() -> VpcLatticeRequestV2ContextBuilder
Create an instance of VpcLatticeRequestV2Context using the builder syntax