#[non_exhaustive]pub struct TimeWindowEventResponseProperties {
pub state: HashMap<String, String>,
}Available on crate feature
chrono only.Expand description
TimeWindowEventResponseProperties is the object that captures response properties that relate to the tumbling windows feature
Kinesis: https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-windows
DDB: https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-windows
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: HashMap<String, String>State being built up to this invoke in the time window.