Available on crate feature
apigw only.Expand description
AWS Lambda event definitions for apigw.
Structs
- ApiGateway
Custom Authorizer Context ApiGatewayCustomAuthorizerContextrepresents the expected format of an API Gateway custom authorizer response. Deprecated. Code should be updated to use the Authorizer map from APIGatewayRequestIdentity. Ex: Authorizer[“principalId”]- ApiGateway
Custom Authorizer Context Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Policy ApiGatewayCustomAuthorizerPolicyrepresents an IAM policy- ApiGateway
Custom Authorizer Policy Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Request ApiGatewayCustomAuthorizerRequestcontains data coming in to a custom API Gateway authorizer function.- ApiGateway
Custom Authorizer Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Request Type Request ApiGatewayCustomAuthorizerRequestTypeRequestcontains data coming in to a custom API Gateway authorizer function.- ApiGateway
Custom Authorizer Request Type Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Request Type Request Context ApiGatewayCustomAuthorizerRequestTypeRequestContextrepresents the expected format of an API Gateway custom authorizer response.- ApiGateway
Custom Authorizer Request Type Request Context Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Request Type Request Identity ApiGatewayCustomAuthorizerRequestTypeRequestIdentitycontains identity information for the request caller including certificate information if using mTLS.- ApiGateway
Custom Authorizer Request Type Request Identity Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Request Type Request Identity Client Cert ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCertcontains certificate information for the request caller if using mTLS.- ApiGateway
Custom Authorizer Request Type Request Identity Client Cert Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Request Type Request Identity Client Cert Validity ApiGatewayCustomAuthorizerRequestTypeRequestIdentityClientCertValiditycontains certificate validity information for the request caller if using mTLS.- ApiGateway
Custom Authorizer Request Type Request Identity Client Cert Validity Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Custom Authorizer Response ApiGatewayCustomAuthorizerResponserepresents the expected format of an API Gateway authorization response.- ApiGateway
Custom Authorizer Response Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Proxy Request ApiGatewayProxyRequestcontains data coming from the API Gateway proxy- ApiGateway
Proxy Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Proxy Request Context ApiGatewayProxyRequestContextcontains the information to identify the AWS account and resources invoking the Lambda function. It also includes Cognito identity information for the caller.- ApiGateway
Proxy Request Context Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Proxy Response ApiGatewayProxyResponseconfigures the response to be returned by API Gateway for the request- ApiGateway
Proxy Response Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Request Authorizer ApiGatewayRequestAuthorizercontains authorizer information for the request context.- ApiGateway
Request Authorizer Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Request Authorizer Cognito Identity ApiGatewayRequestAuthorizerCognitoIdentitycontains Cognito identity information for the request context.- ApiGateway
Request Authorizer Cognito Identity Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Request Authorizer IamDescription ApiGatewayRequestAuthorizerIamDescriptioncontains IAM information for the request context.- ApiGateway
Request Authorizer IamDescription Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Request Authorizer JwtDescription ApiGatewayRequestAuthorizerJwtDescriptioncontains JWT authorizer information for the request context.- ApiGateway
Request Authorizer JwtDescription Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Request Identity ApiGatewayRequestIdentitycontains identity information for the request caller.- ApiGateway
Request Identity Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2Custom Authorizer IamPolicy Response - ApiGateway
V2Custom Authorizer IamPolicy Response Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2Custom Authorizer Simple Response ApiGatewayV2CustomAuthorizerSimpleResponserepresents the simple format of an API Gateway V2 authorization response.- ApiGateway
V2Custom Authorizer Simple Response Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2Custom Authorizer V1Request - ApiGateway
V2Custom Authorizer V1Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2Custom Authorizer V1Request Type Request Context - ApiGateway
V2Custom Authorizer V1Request Type Request Context Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2Custom Authorizer V2Request - ApiGateway
V2Custom Authorizer V2Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Request ApiGatewayV2httpRequestcontains data coming from the new HTTP API Gateway- ApiGateway
V2http Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Request Context ApiGatewayV2httpRequestContextcontains the information to identify the AWS account and resources invoking the Lambda function.- ApiGateway
V2http Request Context Authentication ApiGatewayV2httpRequestContextAuthenticationcontains authentication context information for the request caller including client certificate information if using mTLS.- ApiGateway
V2http Request Context Authentication Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Request Context Authentication Client Cert ApiGatewayV2httpRequestContextAuthenticationClientCertcontains client certificate information for the request caller if using mTLS.- ApiGateway
V2http Request Context Authentication Client Cert Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Request Context Authentication Client Cert Validity ApiGatewayV2httpRequestContextAuthenticationClientCertValiditycontains client certificate validity information for the request caller if using mTLS.- ApiGateway
V2http Request Context Authentication Client Cert Validity Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Request Context Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Request Context Http Description ApiGatewayV2httpRequestContextHttpDescriptioncontains HTTP information for the request context.- ApiGateway
V2http Request Context Http Description Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
V2http Response ApiGatewayV2httpResponseconfigures the response to be returned by API Gateway V2 for the request- ApiGateway
V2http Response Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Websocket Proxy Request ApiGatewayWebsocketProxyRequestcontains data coming from the API Gateway proxy- ApiGateway
Websocket Proxy Request Builder - Use builder syntax to set the inputs and finish with
build(). - ApiGateway
Websocket Proxy Request Context ApiGatewayWebsocketProxyRequestContextcontains the information to identify the AWS account and resources invoking the Lambda function. It also includes Cognito identity information for the caller.- ApiGateway
Websocket Proxy Request Context Builder - Use builder syntax to set the inputs and finish with
build().