pub struct ApiGatewayV2httpRequestBuilder<S: State = Empty> { /* private fields */ }apigw only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ApiGatewayV2httpRequestBuilder<S>
impl<S: State> ApiGatewayV2httpRequestBuilder<S>
Sourcepub fn build(self) -> ApiGatewayV2httpRequestwhere
S: IsComplete,
pub fn build(self) -> ApiGatewayV2httpRequestwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn kind(self, value: String) -> ApiGatewayV2httpRequestBuilder<SetKind<S>>where
S::Kind: IsUnset,
pub fn kind(self, value: String) -> ApiGatewayV2httpRequestBuilder<SetKind<S>>where
S::Kind: IsUnset,
Sourcepub fn maybe_kind(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetKind<S>>where
S::Kind: IsUnset,
pub fn maybe_kind(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetKind<S>>where
S::Kind: IsUnset,
Sourcepub fn method_arn(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetMethodArn<S>>where
S::MethodArn: IsUnset,
pub fn method_arn(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetMethodArn<S>>where
S::MethodArn: IsUnset,
Sourcepub fn maybe_method_arn(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetMethodArn<S>>where
S::MethodArn: IsUnset,
pub fn maybe_method_arn(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetMethodArn<S>>where
S::MethodArn: IsUnset,
Sourcepub fn http_method(
self,
value: Method,
) -> ApiGatewayV2httpRequestBuilder<SetHttpMethod<S>>where
S::HttpMethod: IsUnset,
pub fn http_method(
self,
value: Method,
) -> ApiGatewayV2httpRequestBuilder<SetHttpMethod<S>>where
S::HttpMethod: IsUnset,
Required.
The HTTP method field.
Warning: This field defaults to GET if not present in the payload, which may lead to
incorrect behavior. For standard HTTP API v2 requests, this field is not present in the JSON payload.
Use request_context.http.method instead for standard HTTP API v2 requests, which contains
the actual HTTP method for the request.
This top-level http_method field is only present in Custom Authorizer v1 requests.
For those payloads, use ApiGatewayV2CustomAuthorizerV1Request instead.
Sourcepub fn identity_source(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetIdentitySource<S>>where
S::IdentitySource: IsUnset,
pub fn identity_source(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetIdentitySource<S>>where
S::IdentitySource: IsUnset,
Sourcepub fn maybe_identity_source(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetIdentitySource<S>>where
S::IdentitySource: IsUnset,
pub fn maybe_identity_source(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetIdentitySource<S>>where
S::IdentitySource: IsUnset,
Sourcepub fn resource(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetResource<S>>where
S::Resource: IsUnset,
pub fn resource(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetResource<S>>where
S::Resource: IsUnset,
Sourcepub fn maybe_resource(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetResource<S>>where
S::Resource: IsUnset,
pub fn maybe_resource(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetResource<S>>where
S::Resource: IsUnset,
Sourcepub fn version(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn version(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn maybe_version(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn maybe_version(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn route_key(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetRouteKey<S>>where
S::RouteKey: IsUnset,
pub fn route_key(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetRouteKey<S>>where
S::RouteKey: IsUnset,
Sourcepub fn maybe_route_key(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetRouteKey<S>>where
S::RouteKey: IsUnset,
pub fn maybe_route_key(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetRouteKey<S>>where
S::RouteKey: IsUnset,
Sourcepub fn raw_path(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetRawPath<S>>where
S::RawPath: IsUnset,
pub fn raw_path(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetRawPath<S>>where
S::RawPath: IsUnset,
Sourcepub fn maybe_raw_path(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetRawPath<S>>where
S::RawPath: IsUnset,
pub fn maybe_raw_path(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetRawPath<S>>where
S::RawPath: IsUnset,
Sourcepub fn raw_query_string(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetRawQueryString<S>>where
S::RawQueryString: IsUnset,
pub fn raw_query_string(
self,
value: String,
) -> ApiGatewayV2httpRequestBuilder<SetRawQueryString<S>>where
S::RawQueryString: IsUnset,
Sourcepub fn maybe_raw_query_string(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetRawQueryString<S>>where
S::RawQueryString: IsUnset,
pub fn maybe_raw_query_string(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetRawQueryString<S>>where
S::RawQueryString: IsUnset,
Sourcepub fn headers(
self,
value: HeaderMap,
) -> ApiGatewayV2httpRequestBuilder<SetHeaders<S>>where
S::Headers: IsUnset,
pub fn headers(
self,
value: HeaderMap,
) -> ApiGatewayV2httpRequestBuilder<SetHeaders<S>>where
S::Headers: IsUnset,
Required.
Sourcepub fn query_string_parameters(
self,
value: QueryMap,
) -> ApiGatewayV2httpRequestBuilder<SetQueryStringParameters<S>>where
S::QueryStringParameters: IsUnset,
pub fn query_string_parameters(
self,
value: QueryMap,
) -> ApiGatewayV2httpRequestBuilder<SetQueryStringParameters<S>>where
S::QueryStringParameters: IsUnset,
Required.
Sourcepub fn path_parameters(
self,
value: HashMap<String, String>,
) -> ApiGatewayV2httpRequestBuilder<SetPathParameters<S>>where
S::PathParameters: IsUnset,
pub fn path_parameters(
self,
value: HashMap<String, String>,
) -> ApiGatewayV2httpRequestBuilder<SetPathParameters<S>>where
S::PathParameters: IsUnset,
Required.
Sourcepub fn request_context(
self,
value: ApiGatewayV2httpRequestContext,
) -> ApiGatewayV2httpRequestBuilder<SetRequestContext<S>>where
S::RequestContext: IsUnset,
pub fn request_context(
self,
value: ApiGatewayV2httpRequestContext,
) -> ApiGatewayV2httpRequestBuilder<SetRequestContext<S>>where
S::RequestContext: IsUnset,
Required.
Sourcepub fn stage_variables(
self,
value: HashMap<String, String>,
) -> ApiGatewayV2httpRequestBuilder<SetStageVariables<S>>where
S::StageVariables: IsUnset,
pub fn stage_variables(
self,
value: HashMap<String, String>,
) -> ApiGatewayV2httpRequestBuilder<SetStageVariables<S>>where
S::StageVariables: IsUnset,
Required.
Sourcepub fn body(self, value: String) -> ApiGatewayV2httpRequestBuilder<SetBody<S>>where
S::Body: IsUnset,
pub fn body(self, value: String) -> ApiGatewayV2httpRequestBuilder<SetBody<S>>where
S::Body: IsUnset,
Sourcepub fn maybe_body(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetBody<S>>where
S::Body: IsUnset,
pub fn maybe_body(
self,
value: Option<String>,
) -> ApiGatewayV2httpRequestBuilder<SetBody<S>>where
S::Body: IsUnset,
Sourcepub fn is_base64_encoded(
self,
value: bool,
) -> ApiGatewayV2httpRequestBuilder<SetIsBase64Encoded<S>>where
S::IsBase64Encoded: IsUnset,
pub fn is_base64_encoded(
self,
value: bool,
) -> ApiGatewayV2httpRequestBuilder<SetIsBase64Encoded<S>>where
S::IsBase64Encoded: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ApiGatewayV2httpRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ApiGatewayV2httpRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ApiGatewayV2httpRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ApiGatewayV2httpRequestBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.