pub struct AppSyncDirectResolverEventBuilder<TArguments = Value, TSource = Value, TStash = Value, S: State = Empty>where
TArguments: Serialize + DeserializeOwned,
TSource: Serialize + DeserializeOwned,
TStash: Serialize + DeserializeOwned,{ /* private fields */ }appsync only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<TArguments, TSource, TStash, S: State> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, S>where
TArguments: Serialize + DeserializeOwned,
TSource: Serialize + DeserializeOwned,
TStash: Serialize + DeserializeOwned,
impl<TArguments, TSource, TStash, S: State> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, S>where
TArguments: Serialize + DeserializeOwned,
TSource: Serialize + DeserializeOwned,
TStash: Serialize + DeserializeOwned,
Sourcepub fn build(self) -> AppSyncDirectResolverEvent<TArguments, TSource, TStash>where
S: IsComplete,
pub fn build(self) -> AppSyncDirectResolverEvent<TArguments, TSource, TStash>where
S: IsComplete,
Finish building and return the requested object
Sourcepub fn arguments(
self,
value: TArguments,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetArguments<S>>where
S::Arguments: IsUnset,
pub fn arguments(
self,
value: TArguments,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetArguments<S>>where
S::Arguments: IsUnset,
Sourcepub fn maybe_arguments(
self,
value: Option<TArguments>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetArguments<S>>where
S::Arguments: IsUnset,
pub fn maybe_arguments(
self,
value: Option<TArguments>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetArguments<S>>where
S::Arguments: IsUnset,
Sourcepub fn identity(
self,
value: AppSyncIdentity,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetIdentity<S>>where
S::Identity: IsUnset,
pub fn identity(
self,
value: AppSyncIdentity,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetIdentity<S>>where
S::Identity: IsUnset,
Sourcepub fn maybe_identity(
self,
value: Option<AppSyncIdentity>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetIdentity<S>>where
S::Identity: IsUnset,
pub fn maybe_identity(
self,
value: Option<AppSyncIdentity>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetIdentity<S>>where
S::Identity: IsUnset,
Sourcepub fn source(
self,
value: TSource,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetSource<S>>where
S::Source: IsUnset,
pub fn source(
self,
value: TSource,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetSource<S>>where
S::Source: IsUnset,
Sourcepub fn maybe_source(
self,
value: Option<TSource>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetSource<S>>where
S::Source: IsUnset,
pub fn maybe_source(
self,
value: Option<TSource>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetSource<S>>where
S::Source: IsUnset,
Sourcepub fn request(
self,
value: AppSyncRequest,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetRequest<S>>where
S::Request: IsUnset,
pub fn request(
self,
value: AppSyncRequest,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetRequest<S>>where
S::Request: IsUnset,
Required.
Sourcepub fn info(
self,
value: AppSyncInfo,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetInfo<S>>where
S::Info: IsUnset,
pub fn info(
self,
value: AppSyncInfo,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetInfo<S>>where
S::Info: IsUnset,
Required.
Sourcepub fn prev(
self,
value: AppSyncPrevResult,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetPrev<S>>where
S::Prev: IsUnset,
pub fn prev(
self,
value: AppSyncPrevResult,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetPrev<S>>where
S::Prev: IsUnset,
Sourcepub fn maybe_prev(
self,
value: Option<AppSyncPrevResult>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetPrev<S>>where
S::Prev: IsUnset,
pub fn maybe_prev(
self,
value: Option<AppSyncPrevResult>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetPrev<S>>where
S::Prev: IsUnset,
Sourcepub fn stash(
self,
value: TStash,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetStash<S>>where
S::Stash: IsUnset,
pub fn stash(
self,
value: TStash,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetStash<S>>where
S::Stash: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AppSyncDirectResolverEventBuilder<TArguments, TSource, TStash, SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.