pub struct AutoScalingEventBuilder<T1 = Value, S: State = Empty>where
T1: DeserializeOwned + Serialize,{ /* private fields */ }autoscaling only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<T1, S: State> AutoScalingEventBuilder<T1, S>where
T1: DeserializeOwned + Serialize,
impl<T1, S: State> AutoScalingEventBuilder<T1, S>where
T1: DeserializeOwned + Serialize,
Sourcepub fn build(self) -> AutoScalingEvent<T1>where
S: IsComplete,
pub fn build(self) -> AutoScalingEvent<T1>where
S: IsComplete,
Finish building and return the requested object
Sourcepub fn version(
self,
value: String,
) -> AutoScalingEventBuilder<T1, SetVersion<S>>where
S::Version: IsUnset,
pub fn version(
self,
value: String,
) -> AutoScalingEventBuilder<T1, SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn maybe_version(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetVersion<S>>where
S::Version: IsUnset,
pub fn maybe_version(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn id(self, value: String) -> AutoScalingEventBuilder<T1, SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: String) -> AutoScalingEventBuilder<T1, SetId<S>>where
S::Id: IsUnset,
Sourcepub fn maybe_id(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetId<S>>where
S::Id: IsUnset,
pub fn maybe_id(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetId<S>>where
S::Id: IsUnset,
Sourcepub fn detail_type(
self,
value: String,
) -> AutoScalingEventBuilder<T1, SetDetailType<S>>where
S::DetailType: IsUnset,
pub fn detail_type(
self,
value: String,
) -> AutoScalingEventBuilder<T1, SetDetailType<S>>where
S::DetailType: IsUnset,
Sourcepub fn maybe_detail_type(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetDetailType<S>>where
S::DetailType: IsUnset,
pub fn maybe_detail_type(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetDetailType<S>>where
S::DetailType: IsUnset,
Sourcepub fn source(self, value: String) -> AutoScalingEventBuilder<T1, SetSource<S>>where
S::Source: IsUnset,
pub fn source(self, value: String) -> AutoScalingEventBuilder<T1, SetSource<S>>where
S::Source: IsUnset,
Sourcepub fn maybe_source(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetSource<S>>where
S::Source: IsUnset,
pub fn maybe_source(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetSource<S>>where
S::Source: IsUnset,
Sourcepub fn account_id(
self,
value: String,
) -> AutoScalingEventBuilder<T1, SetAccountId<S>>where
S::AccountId: IsUnset,
pub fn account_id(
self,
value: String,
) -> AutoScalingEventBuilder<T1, SetAccountId<S>>where
S::AccountId: IsUnset,
Sourcepub fn maybe_account_id(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetAccountId<S>>where
S::AccountId: IsUnset,
pub fn maybe_account_id(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetAccountId<S>>where
S::AccountId: IsUnset,
Sourcepub fn time(
self,
value: DateTime<Utc>,
) -> AutoScalingEventBuilder<T1, SetTime<S>>where
S::Time: IsUnset,
pub fn time(
self,
value: DateTime<Utc>,
) -> AutoScalingEventBuilder<T1, SetTime<S>>where
S::Time: IsUnset,
Required.
Event timestamp
Sourcepub fn region(self, value: String) -> AutoScalingEventBuilder<T1, SetRegion<S>>where
S::Region: IsUnset,
pub fn region(self, value: String) -> AutoScalingEventBuilder<T1, SetRegion<S>>where
S::Region: IsUnset,
Sourcepub fn maybe_region(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetRegion<S>>where
S::Region: IsUnset,
pub fn maybe_region(
self,
value: Option<String>,
) -> AutoScalingEventBuilder<T1, SetRegion<S>>where
S::Region: IsUnset,
Sourcepub fn resources(
self,
value: Vec<String>,
) -> AutoScalingEventBuilder<T1, SetResources<S>>where
S::Resources: IsUnset,
pub fn resources(
self,
value: Vec<String>,
) -> AutoScalingEventBuilder<T1, SetResources<S>>where
S::Resources: IsUnset,
Required.
Information about resources impacted by event
Sourcepub fn detail(
self,
value: HashMap<String, T1>,
) -> AutoScalingEventBuilder<T1, SetDetail<S>>where
S::Detail: IsUnset,
pub fn detail(
self,
value: HashMap<String, T1>,
) -> AutoScalingEventBuilder<T1, SetDetail<S>>where
S::Detail: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> AutoScalingEventBuilder<T1, SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> AutoScalingEventBuilder<T1, SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AutoScalingEventBuilder<T1, SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> AutoScalingEventBuilder<T1, SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.