Available on crate feature
bedrock_agent_runtime only.Expand description
AWS Lambda event definitions for agent for amazon bedrock
Structs
- Agent
- Agent
Builder - Use builder syntax to set the inputs and finish with
build(). - Agent
Event - The Event sent to Lambda from Agents for Amazon Bedrock.
- Agent
Event Builder - Use builder syntax to set the inputs and finish with
build(). - Content
- Content
Builder - Use builder syntax to set the inputs and finish with
build(). - Parameter
- Parameter
Builder - Use builder syntax to set the inputs and finish with
build(). - Property
- Property
Builder - Use builder syntax to set the inputs and finish with
build(). - Request
Body - Request
Body Builder - Use builder syntax to set the inputs and finish with
build().