pub struct ConfigurationComplianceStateChangeBuilder<S: State = Empty> { /* private fields */ }cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ConfigurationComplianceStateChangeBuilder<S>
impl<S: State> ConfigurationComplianceStateChangeBuilder<S>
Sourcepub fn build(self) -> ConfigurationComplianceStateChangewhere
S: IsComplete,
pub fn build(self) -> ConfigurationComplianceStateChangewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn last_runtime(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetLastRuntime<S>>where
S::LastRuntime: IsUnset,
pub fn last_runtime(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetLastRuntime<S>>where
S::LastRuntime: IsUnset,
Sourcepub fn maybe_last_runtime(
self,
value: Option<String>,
) -> ConfigurationComplianceStateChangeBuilder<SetLastRuntime<S>>where
S::LastRuntime: IsUnset,
pub fn maybe_last_runtime(
self,
value: Option<String>,
) -> ConfigurationComplianceStateChangeBuilder<SetLastRuntime<S>>where
S::LastRuntime: IsUnset,
Sourcepub fn compliance_status(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetComplianceStatus<S>>where
S::ComplianceStatus: IsUnset,
pub fn compliance_status(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetComplianceStatus<S>>where
S::ComplianceStatus: IsUnset,
Required.
Sourcepub fn resource_type(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetResourceType<S>>where
S::ResourceType: IsUnset,
pub fn resource_type(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetResourceType<S>>where
S::ResourceType: IsUnset,
Required.
Sourcepub fn resource_id(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetResourceId<S>>where
S::ResourceId: IsUnset,
pub fn resource_id(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetResourceId<S>>where
S::ResourceId: IsUnset,
Required.
Sourcepub fn compliance_type(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetComplianceType<S>>where
S::ComplianceType: IsUnset,
pub fn compliance_type(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetComplianceType<S>>where
S::ComplianceType: IsUnset,
Required.
Sourcepub fn patch_baseline_id(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetPatchBaselineId<S>>where
S::PatchBaselineId: IsUnset,
pub fn patch_baseline_id(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetPatchBaselineId<S>>where
S::PatchBaselineId: IsUnset,
Sourcepub fn maybe_patch_baseline_id(
self,
value: Option<String>,
) -> ConfigurationComplianceStateChangeBuilder<SetPatchBaselineId<S>>where
S::PatchBaselineId: IsUnset,
pub fn maybe_patch_baseline_id(
self,
value: Option<String>,
) -> ConfigurationComplianceStateChangeBuilder<SetPatchBaselineId<S>>where
S::PatchBaselineId: IsUnset,
Sourcepub fn serverity(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetServerity<S>>where
S::Serverity: IsUnset,
pub fn serverity(
self,
value: String,
) -> ConfigurationComplianceStateChangeBuilder<SetServerity<S>>where
S::Serverity: IsUnset,
Sourcepub fn maybe_serverity(
self,
value: Option<String>,
) -> ConfigurationComplianceStateChangeBuilder<SetServerity<S>>where
S::Serverity: IsUnset,
pub fn maybe_serverity(
self,
value: Option<String>,
) -> ConfigurationComplianceStateChangeBuilder<SetServerity<S>>where
S::Serverity: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ConfigurationComplianceStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ConfigurationComplianceStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ConfigurationComplianceStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ConfigurationComplianceStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.