pub struct EC2StateManagerAssociationStateChangeBuilder<S: State = Empty> { /* private fields */ }cloudwatch_events only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> EC2StateManagerAssociationStateChangeBuilder<S>
impl<S: State> EC2StateManagerAssociationStateChangeBuilder<S>
Sourcepub fn build(self) -> EC2StateManagerAssociationStateChangewhere
S: IsComplete,
pub fn build(self) -> EC2StateManagerAssociationStateChangewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn association_id(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationId<S>>where
S::AssociationId: IsUnset,
pub fn association_id(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationId<S>>where
S::AssociationId: IsUnset,
Required.
Sourcepub fn document_name(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetDocumentName<S>>where
S::DocumentName: IsUnset,
pub fn document_name(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetDocumentName<S>>where
S::DocumentName: IsUnset,
Required.
Sourcepub fn association_version(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationVersion<S>>where
S::AssociationVersion: IsUnset,
pub fn association_version(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationVersion<S>>where
S::AssociationVersion: IsUnset,
Required.
Sourcepub fn document_version(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetDocumentVersion<S>>where
S::DocumentVersion: IsUnset,
pub fn document_version(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetDocumentVersion<S>>where
S::DocumentVersion: IsUnset,
Required.
Sourcepub fn targets(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetTargets<S>>where
S::Targets: IsUnset,
pub fn targets(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetTargets<S>>where
S::Targets: IsUnset,
Required.
Sourcepub fn creation_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetCreationDate<S>>where
S::CreationDate: IsUnset,
pub fn creation_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetCreationDate<S>>where
S::CreationDate: IsUnset,
Required.
Sourcepub fn last_successful_execution_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetLastSuccessfulExecutionDate<S>>where
S::LastSuccessfulExecutionDate: IsUnset,
pub fn last_successful_execution_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetLastSuccessfulExecutionDate<S>>where
S::LastSuccessfulExecutionDate: IsUnset,
Required.
Sourcepub fn last_execution_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetLastExecutionDate<S>>where
S::LastExecutionDate: IsUnset,
pub fn last_execution_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetLastExecutionDate<S>>where
S::LastExecutionDate: IsUnset,
Required.
Sourcepub fn last_updated_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetLastUpdatedDate<S>>where
S::LastUpdatedDate: IsUnset,
pub fn last_updated_date(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetLastUpdatedDate<S>>where
S::LastUpdatedDate: IsUnset,
Required.
Sourcepub fn status(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetStatus<S>>where
S::Status: IsUnset,
pub fn status(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetStatus<S>>where
S::Status: IsUnset,
Required.
Sourcepub fn association_status_aggregated_count(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationStatusAggregatedCount<S>>where
S::AssociationStatusAggregatedCount: IsUnset,
pub fn association_status_aggregated_count(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationStatusAggregatedCount<S>>where
S::AssociationStatusAggregatedCount: IsUnset,
Required.
Sourcepub fn schedule_expression(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetScheduleExpression<S>>where
S::ScheduleExpression: IsUnset,
pub fn schedule_expression(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetScheduleExpression<S>>where
S::ScheduleExpression: IsUnset,
Required.
Sourcepub fn association_cwe_version(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationCweVersion<S>>where
S::AssociationCweVersion: IsUnset,
pub fn association_cwe_version(
self,
value: String,
) -> EC2StateManagerAssociationStateChangeBuilder<SetAssociationCweVersion<S>>where
S::AssociationCweVersion: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> EC2StateManagerAssociationStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> EC2StateManagerAssociationStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> EC2StateManagerAssociationStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> EC2StateManagerAssociationStateChangeBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.