pub struct CodePipelineEventDetailBuilder<S: State = Empty> { /* private fields */ }codepipeline_cloudwatch only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CodePipelineEventDetailBuilder<S>
impl<S: State> CodePipelineEventDetailBuilder<S>
Sourcepub fn build(self) -> CodePipelineEventDetailwhere
S: IsComplete,
pub fn build(self) -> CodePipelineEventDetailwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn pipeline(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetPipeline<S>>where
S::Pipeline: IsUnset,
pub fn pipeline(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetPipeline<S>>where
S::Pipeline: IsUnset,
Sourcepub fn maybe_pipeline(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetPipeline<S>>where
S::Pipeline: IsUnset,
pub fn maybe_pipeline(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetPipeline<S>>where
S::Pipeline: IsUnset,
Sourcepub fn version(
self,
value: i64,
) -> CodePipelineEventDetailBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn version(
self,
value: i64,
) -> CodePipelineEventDetailBuilder<SetVersion<S>>where
S::Version: IsUnset,
Required.
From live testing this is always int64 not string as documented
Sourcepub fn execution_id(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetExecutionId<S>>where
S::ExecutionId: IsUnset,
pub fn execution_id(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetExecutionId<S>>where
S::ExecutionId: IsUnset,
Sourcepub fn maybe_execution_id(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetExecutionId<S>>where
S::ExecutionId: IsUnset,
pub fn maybe_execution_id(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetExecutionId<S>>where
S::ExecutionId: IsUnset,
Sourcepub fn stage(self, value: String) -> CodePipelineEventDetailBuilder<SetStage<S>>where
S::Stage: IsUnset,
pub fn stage(self, value: String) -> CodePipelineEventDetailBuilder<SetStage<S>>where
S::Stage: IsUnset,
Sourcepub fn maybe_stage(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetStage<S>>where
S::Stage: IsUnset,
pub fn maybe_stage(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetStage<S>>where
S::Stage: IsUnset,
Sourcepub fn action(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetAction<S>>where
S::Action: IsUnset,
pub fn action(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetAction<S>>where
S::Action: IsUnset,
Sourcepub fn maybe_action(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetAction<S>>where
S::Action: IsUnset,
pub fn maybe_action(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetAction<S>>where
S::Action: IsUnset,
Sourcepub fn state(
self,
value: CodePipelineState,
) -> CodePipelineEventDetailBuilder<SetState<S>>where
S::State: IsUnset,
pub fn state(
self,
value: CodePipelineState,
) -> CodePipelineEventDetailBuilder<SetState<S>>where
S::State: IsUnset,
Required.
Sourcepub fn region(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetRegion<S>>where
S::Region: IsUnset,
pub fn region(
self,
value: String,
) -> CodePipelineEventDetailBuilder<SetRegion<S>>where
S::Region: IsUnset,
Sourcepub fn maybe_region(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetRegion<S>>where
S::Region: IsUnset,
pub fn maybe_region(
self,
value: Option<String>,
) -> CodePipelineEventDetailBuilder<SetRegion<S>>where
S::Region: IsUnset,
Sourcepub fn type_(
self,
value: CodePipelineEventDetailType,
) -> CodePipelineEventDetailBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn type_(
self,
value: CodePipelineEventDetailType,
) -> CodePipelineEventDetailBuilder<SetType<S>>where
S::Type: IsUnset,
Sourcepub fn maybe_type_(
self,
value: Option<CodePipelineEventDetailType>,
) -> CodePipelineEventDetailBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn maybe_type_(
self,
value: Option<CodePipelineEventDetailType>,
) -> CodePipelineEventDetailBuilder<SetType<S>>where
S::Type: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CodePipelineEventDetailBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CodePipelineEventDetailBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CodePipelineEventDetailBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CodePipelineEventDetailBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.