pub struct CognitoEventBuilder<S: State = Empty> { /* private fields */ }cognito only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CognitoEventBuilder<S>
impl<S: State> CognitoEventBuilder<S>
Sourcepub fn build(self) -> CognitoEventwhere
S: IsComplete,
pub fn build(self) -> CognitoEventwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn dataset_name(
self,
value: String,
) -> CognitoEventBuilder<SetDatasetName<S>>where
S::DatasetName: IsUnset,
pub fn dataset_name(
self,
value: String,
) -> CognitoEventBuilder<SetDatasetName<S>>where
S::DatasetName: IsUnset,
Sourcepub fn maybe_dataset_name(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetDatasetName<S>>where
S::DatasetName: IsUnset,
pub fn maybe_dataset_name(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetDatasetName<S>>where
S::DatasetName: IsUnset,
Sourcepub fn dataset_records(
self,
value: HashMap<String, CognitoDatasetRecord>,
) -> CognitoEventBuilder<SetDatasetRecords<S>>where
S::DatasetRecords: IsUnset,
pub fn dataset_records(
self,
value: HashMap<String, CognitoDatasetRecord>,
) -> CognitoEventBuilder<SetDatasetRecords<S>>where
S::DatasetRecords: IsUnset,
Required.
Sourcepub fn event_type(self, value: String) -> CognitoEventBuilder<SetEventType<S>>where
S::EventType: IsUnset,
pub fn event_type(self, value: String) -> CognitoEventBuilder<SetEventType<S>>where
S::EventType: IsUnset,
Sourcepub fn maybe_event_type(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetEventType<S>>where
S::EventType: IsUnset,
pub fn maybe_event_type(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetEventType<S>>where
S::EventType: IsUnset,
Sourcepub fn identity_id(self, value: String) -> CognitoEventBuilder<SetIdentityId<S>>where
S::IdentityId: IsUnset,
pub fn identity_id(self, value: String) -> CognitoEventBuilder<SetIdentityId<S>>where
S::IdentityId: IsUnset,
Sourcepub fn maybe_identity_id(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetIdentityId<S>>where
S::IdentityId: IsUnset,
pub fn maybe_identity_id(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetIdentityId<S>>where
S::IdentityId: IsUnset,
Sourcepub fn identity_pool_id(
self,
value: String,
) -> CognitoEventBuilder<SetIdentityPoolId<S>>where
S::IdentityPoolId: IsUnset,
pub fn identity_pool_id(
self,
value: String,
) -> CognitoEventBuilder<SetIdentityPoolId<S>>where
S::IdentityPoolId: IsUnset,
Sourcepub fn maybe_identity_pool_id(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetIdentityPoolId<S>>where
S::IdentityPoolId: IsUnset,
pub fn maybe_identity_pool_id(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetIdentityPoolId<S>>where
S::IdentityPoolId: IsUnset,
Sourcepub fn region(self, value: String) -> CognitoEventBuilder<SetRegion<S>>where
S::Region: IsUnset,
pub fn region(self, value: String) -> CognitoEventBuilder<SetRegion<S>>where
S::Region: IsUnset,
Sourcepub fn maybe_region(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetRegion<S>>where
S::Region: IsUnset,
pub fn maybe_region(
self,
value: Option<String>,
) -> CognitoEventBuilder<SetRegion<S>>where
S::Region: IsUnset,
Sourcepub fn version(self, value: i64) -> CognitoEventBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn version(self, value: i64) -> CognitoEventBuilder<SetVersion<S>>where
S::Version: IsUnset,
Required.
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> CognitoEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> CognitoEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CognitoEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> CognitoEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.