Available on crate feature
connect only.Expand description
AWS Lambda event definitions for connect.
Structs
- Connect
Contact Data ConnectContactDataholds all of the contact information for the user that invoked the Connect event.- Connect
Contact Data Builder - Use builder syntax to set the inputs and finish with
build(). - Connect
Details ConnectDetailsholds the details of a Connect event- Connect
Details Builder - Use builder syntax to set the inputs and finish with
build(). - Connect
Endpoint ConnectEndpointrepresents routing information.- Connect
Endpoint Builder - Use builder syntax to set the inputs and finish with
build(). - Connect
Event ConnectEventcontains the data structure for a Connect event.- Connect
Event Builder - Use builder syntax to set the inputs and finish with
build(). - Connect
Queue ConnectQueuerepresents a queue object.- Connect
Queue Builder - Use builder syntax to set the inputs and finish with
build().