pub struct ChangeDropEventBuilder<S: State = Empty> { /* private fields */ }documentdb only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ChangeDropEventBuilder<S>
impl<S: State> ChangeDropEventBuilder<S>
Sourcepub fn build(self) -> ChangeDropEventwhere
S: IsComplete,
pub fn build(self) -> ChangeDropEventwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn id(self, value: DocumentId) -> ChangeDropEventBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: DocumentId) -> ChangeDropEventBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Sourcepub fn cluster_time(
self,
value: Timestamp,
) -> ChangeDropEventBuilder<SetClusterTime<S>>where
S::ClusterTime: IsUnset,
pub fn cluster_time(
self,
value: Timestamp,
) -> ChangeDropEventBuilder<SetClusterTime<S>>where
S::ClusterTime: IsUnset,
Sourcepub fn maybe_cluster_time(
self,
value: Option<Timestamp>,
) -> ChangeDropEventBuilder<SetClusterTime<S>>where
S::ClusterTime: IsUnset,
pub fn maybe_cluster_time(
self,
value: Option<Timestamp>,
) -> ChangeDropEventBuilder<SetClusterTime<S>>where
S::ClusterTime: IsUnset,
Sourcepub fn ls_id(self, value: AnyDocument) -> ChangeDropEventBuilder<SetLsId<S>>where
S::LsId: IsUnset,
pub fn ls_id(self, value: AnyDocument) -> ChangeDropEventBuilder<SetLsId<S>>where
S::LsId: IsUnset,
Sourcepub fn maybe_ls_id(
self,
value: Option<AnyDocument>,
) -> ChangeDropEventBuilder<SetLsId<S>>where
S::LsId: IsUnset,
pub fn maybe_ls_id(
self,
value: Option<AnyDocument>,
) -> ChangeDropEventBuilder<SetLsId<S>>where
S::LsId: IsUnset,
Sourcepub fn ns(self, value: DatabaseCollection) -> ChangeDropEventBuilder<SetNs<S>>where
S::Ns: IsUnset,
pub fn ns(self, value: DatabaseCollection) -> ChangeDropEventBuilder<SetNs<S>>where
S::Ns: IsUnset,
Required.
Sourcepub fn txn_number(
self,
value: String,
) -> ChangeDropEventBuilder<SetTxnNumber<S>>where
S::TxnNumber: IsUnset,
pub fn txn_number(
self,
value: String,
) -> ChangeDropEventBuilder<SetTxnNumber<S>>where
S::TxnNumber: IsUnset,
Sourcepub fn maybe_txn_number(
self,
value: Option<String>,
) -> ChangeDropEventBuilder<SetTxnNumber<S>>where
S::TxnNumber: IsUnset,
pub fn maybe_txn_number(
self,
value: Option<String>,
) -> ChangeDropEventBuilder<SetTxnNumber<S>>where
S::TxnNumber: IsUnset,
Sourcepub fn other(
self,
value: Map<String, Value>,
) -> ChangeDropEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(
self,
value: Map<String, Value>,
) -> ChangeDropEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ChangeDropEventBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> ChangeDropEventBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.