Available on crate feature
dynamodb only.Expand description
AWS Lambda event definitions for dynamodb.
Structs
- Event
- The
Eventstream event handled to Lambda http://docs.aws.amazon.com/lambda/latest/dg/eventsources.html#eventsources-ddb-update - Event
Builder - Use builder syntax to set the inputs and finish with
build(). - Event
Record - EventRecord stores information about each record of a DynamoDb stream event
- Event
Record Builder - Use builder syntax to set the inputs and finish with
build(). - Stream
Record DynamoDbStreamRecordrepresents a description of a single data modification that was performed on an item in a DynamoDB table.- Stream
Record Builder - Use builder syntax to set the inputs and finish with
build(). - Time
Window Event TimeWindowEventrepresents an Amazon Dynamodb event when using time windows ref. https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-windows- Time
Window Event Builder - Use builder syntax to set the inputs and finish with
build(). - Time
Window Event Response TimeWindowEventResponseis the outer structure to report batch item failures for DynamoDBTimeWindowEvent.- Time
Window Event Response Builder - Use builder syntax to set the inputs and finish with
build(). - User
Identity - User
Identity Builder - Use builder syntax to set the inputs and finish with
build().