pub struct EventRecordBuilder<S: State = Empty> { /* private fields */ }dynamodb only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> EventRecordBuilder<S>
impl<S: State> EventRecordBuilder<S>
Sourcepub fn build(self) -> EventRecordwhere
S: IsComplete,
pub fn build(self) -> EventRecordwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn aws_region(self, value: String) -> EventRecordBuilder<SetAwsRegion<S>>where
S::AwsRegion: IsUnset,
pub fn aws_region(self, value: String) -> EventRecordBuilder<SetAwsRegion<S>>where
S::AwsRegion: IsUnset,
Required.
The region in which the GetRecords request was received.
Sourcepub fn change(self, value: StreamRecord) -> EventRecordBuilder<SetChange<S>>where
S::Change: IsUnset,
pub fn change(self, value: StreamRecord) -> EventRecordBuilder<SetChange<S>>where
S::Change: IsUnset,
Required.
The main body of the stream record, containing all of the DynamoDB-specific fields.
Sourcepub fn event_id(self, value: String) -> EventRecordBuilder<SetEventId<S>>where
S::EventId: IsUnset,
pub fn event_id(self, value: String) -> EventRecordBuilder<SetEventId<S>>where
S::EventId: IsUnset,
Required.
A globally unique identifier for the event that was recorded in this stream record.
Sourcepub fn event_name(self, value: String) -> EventRecordBuilder<SetEventName<S>>where
S::EventName: IsUnset,
pub fn event_name(self, value: String) -> EventRecordBuilder<SetEventName<S>>where
S::EventName: IsUnset,
Required.
The type of data modification that was performed on the DynamoDB table:
-
INSERT - a new item was added to the table.
-
MODIFY - one or more of an existing item’s attributes were modified.
-
REMOVE - the item was deleted from the table
Sourcepub fn event_source(
self,
value: String,
) -> EventRecordBuilder<SetEventSource<S>>where
S::EventSource: IsUnset,
pub fn event_source(
self,
value: String,
) -> EventRecordBuilder<SetEventSource<S>>where
S::EventSource: IsUnset,
Sourcepub fn maybe_event_source(
self,
value: Option<String>,
) -> EventRecordBuilder<SetEventSource<S>>where
S::EventSource: IsUnset,
pub fn maybe_event_source(
self,
value: Option<String>,
) -> EventRecordBuilder<SetEventSource<S>>where
S::EventSource: IsUnset,
Sourcepub fn event_version(
self,
value: String,
) -> EventRecordBuilder<SetEventVersion<S>>where
S::EventVersion: IsUnset,
pub fn event_version(
self,
value: String,
) -> EventRecordBuilder<SetEventVersion<S>>where
S::EventVersion: IsUnset,
Optional (Some / Option setters). The version number of the stream record format. This number is updated whenever the structure of Record is modified.
Client applications must not assume that eventVersion will remain at a particular value, as this number is subject to change at any time. In general, eventVersion will only increase as the low-level DynamoDB Streams API evolves.
Sourcepub fn maybe_event_version(
self,
value: Option<String>,
) -> EventRecordBuilder<SetEventVersion<S>>where
S::EventVersion: IsUnset,
pub fn maybe_event_version(
self,
value: Option<String>,
) -> EventRecordBuilder<SetEventVersion<S>>where
S::EventVersion: IsUnset,
Optional (Some / Option setters). The version number of the stream record format. This number is updated whenever the structure of Record is modified.
Client applications must not assume that eventVersion will remain at a particular value, as this number is subject to change at any time. In general, eventVersion will only increase as the low-level DynamoDB Streams API evolves.
Sourcepub fn event_source_arn(
self,
value: String,
) -> EventRecordBuilder<SetEventSourceArn<S>>where
S::EventSourceArn: IsUnset,
pub fn event_source_arn(
self,
value: String,
) -> EventRecordBuilder<SetEventSourceArn<S>>where
S::EventSourceArn: IsUnset,
Sourcepub fn maybe_event_source_arn(
self,
value: Option<String>,
) -> EventRecordBuilder<SetEventSourceArn<S>>where
S::EventSourceArn: IsUnset,
pub fn maybe_event_source_arn(
self,
value: Option<String>,
) -> EventRecordBuilder<SetEventSourceArn<S>>where
S::EventSourceArn: IsUnset,
Sourcepub fn user_identity(
self,
value: UserIdentity,
) -> EventRecordBuilder<SetUserIdentity<S>>where
S::UserIdentity: IsUnset,
pub fn user_identity(
self,
value: UserIdentity,
) -> EventRecordBuilder<SetUserIdentity<S>>where
S::UserIdentity: IsUnset,
Sourcepub fn maybe_user_identity(
self,
value: Option<UserIdentity>,
) -> EventRecordBuilder<SetUserIdentity<S>>where
S::UserIdentity: IsUnset,
pub fn maybe_user_identity(
self,
value: Option<UserIdentity>,
) -> EventRecordBuilder<SetUserIdentity<S>>where
S::UserIdentity: IsUnset,
Sourcepub fn record_format(
self,
value: String,
) -> EventRecordBuilder<SetRecordFormat<S>>where
S::RecordFormat: IsUnset,
pub fn record_format(
self,
value: String,
) -> EventRecordBuilder<SetRecordFormat<S>>where
S::RecordFormat: IsUnset,
Sourcepub fn maybe_record_format(
self,
value: Option<String>,
) -> EventRecordBuilder<SetRecordFormat<S>>where
S::RecordFormat: IsUnset,
pub fn maybe_record_format(
self,
value: Option<String>,
) -> EventRecordBuilder<SetRecordFormat<S>>where
S::RecordFormat: IsUnset,
Sourcepub fn table_name(self, value: String) -> EventRecordBuilder<SetTableName<S>>where
S::TableName: IsUnset,
pub fn table_name(self, value: String) -> EventRecordBuilder<SetTableName<S>>where
S::TableName: IsUnset,
Sourcepub fn maybe_table_name(
self,
value: Option<String>,
) -> EventRecordBuilder<SetTableName<S>>where
S::TableName: IsUnset,
pub fn maybe_table_name(
self,
value: Option<String>,
) -> EventRecordBuilder<SetTableName<S>>where
S::TableName: IsUnset,
Sourcepub fn other(self, value: Map<String, Value>) -> EventRecordBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn other(self, value: Map<String, Value>) -> EventRecordBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.
Sourcepub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> EventRecordBuilder<SetOther<S>>where
S::Other: IsUnset,
pub fn maybe_other(
self,
value: Option<Map<String, Value>>,
) -> EventRecordBuilder<SetOther<S>>where
S::Other: IsUnset,
Optional (Some / Option setters).
Default: <serde_json::Map<String, Value> as Default>::default().
Catchall to catch any additional fields that were present but not explicitly defined by this struct.
Enabled with Cargo feature catch-all-fields.
If catch-all-fields is disabled, any additional fields that are present will be ignored.