Available on crate feature
ecr_scan only.Expand description
AWS Lambda event definitions for ecr_scan.
Structs
- EcrScan
Event - EcrScan
Event Builder - Use builder syntax to set the inputs and finish with
build(). - EcrScan
Event Detail Type - EcrScan
Event Detail Type Builder - Use builder syntax to set the inputs and finish with
build(). - EcrScan
Event Finding Severity Counts - EcrScan
Event Finding Severity Counts Builder - Use builder syntax to set the inputs and finish with
build().