Available on crate feature
iot_1_click only.Expand description
AWS Lambda event definitions for iot_1_click.
Structs
- IoTOne
Click Button Clicked - IoTOne
Click Button Clicked Builder - Use builder syntax to set the inputs and finish with
build(). - IoTOne
Click Device Event - IoTOne
Click Device Event Builder - Use builder syntax to set the inputs and finish with
build(). - IoTOne
Click Device Info - IoTOne
Click Device Info Builder - Use builder syntax to set the inputs and finish with
build(). - IoTOne
Click Event IoTOneClickEventrepresents a click event published by clicking button type device.- IoTOne
Click Event Builder - Use builder syntax to set the inputs and finish with
build(). - IoTOne
Click Placement Info - IoTOne
Click Placement Info Builder - Use builder syntax to set the inputs and finish with
build().