Available on crate feature
kinesis only.Expand description
AWS Lambda event definitions for kinesis.
Modules
Structs
- Kinesis
Event - Kinesis
Event Builder - Use builder syntax to set the inputs and finish with
build(). - Kinesis
Event Record - Kinesis
Event Record Builder - Use builder syntax to set the inputs and finish with
build(). - Kinesis
Record - Kinesis
Record Builder - Use builder syntax to set the inputs and finish with
build(). - Kinesis
Time Window Event KinesisTimeWindowEventrepresents an Amazon Dynamodb event when using time windows ref. https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-windows- Kinesis
Time Window Event Builder - Use builder syntax to set the inputs and finish with
build(). - Kinesis
Time Window Event Response KinesisTimeWindowEventResponseis the outer structure to report batch item failures for KinesisTimeWindowEvent.- Kinesis
Time Window Event Response Builder - Use builder syntax to set the inputs and finish with
build().