Available on crate feature
s3 only.Expand description
AWS Lambda event definitions for s3.
Modules
Structs
- S3Bucket
- S3Bucket
Builder - Use builder syntax to set the inputs and finish with
build(). - S3Entity
- S3Entity
Builder - Use builder syntax to set the inputs and finish with
build(). - S3Event
S3Eventwhich wrap an array ofS3EventRecord- S3Event
Builder - Use builder syntax to set the inputs and finish with
build(). - S3Event
Record S3EventRecordwhich wrap record data- S3Event
Record Builder - Use builder syntax to set the inputs and finish with
build(). - S3Object
- S3Object
Builder - Use builder syntax to set the inputs and finish with
build(). - S3Request
Parameters - S3Request
Parameters Builder - Use builder syntax to set the inputs and finish with
build(). - S3User
Identity - S3User
Identity Builder - Use builder syntax to set the inputs and finish with
build().