Available on crate feature
s3 only.Structs
- S3Batch
Job S3BatchJobwhichs have the job id- S3Batch
JobBuilder - Use builder syntax to set the inputs and finish with
build(). - S3Batch
JobEvent S3BatchJobEventencapsulates the detail of a s3 batch job- S3Batch
JobEvent Builder - Use builder syntax to set the inputs and finish with
build(). - S3Batch
JobResponse S3BatchJobResponseis the response of a iven s3 batch job with the results- S3Batch
JobResponse Builder - Use builder syntax to set the inputs and finish with
build(). - S3Batch
JobResult S3BatchJobResultrepresents the result of a given task- S3Batch
JobResult Builder - Use builder syntax to set the inputs and finish with
build(). - S3Batch
JobTask S3BatchJobTaskrepresents one task in the s3 batch job and have all task details- S3Batch
JobTask Builder - Use builder syntax to set the inputs and finish with
build().