Available on crate feature
s3 only.Structs
- Configuration
Configurationcontains information about the Object Lambda access point- Configuration
Builder - Use builder syntax to set the inputs and finish with
build(). - GetObject
Context GetObjectContextcontains the input and output details for connections to Amazon S3 and S3 Object Lambda- GetObject
Context Builder - Use builder syntax to set the inputs and finish with
build(). - Head
Object Context HeadObjectContextfor connections to Amazon S3 and S3 Object Lambda- Head
Object Context Builder - Use builder syntax to set the inputs and finish with
build(). - List
Objects Context ListObjectsContextfor connections to Amazon S3 and S3 Object Lambda- List
Objects Context Builder - Use builder syntax to set the inputs and finish with
build(). - List
Objects V2Context ListObjectsV2Contextfor connections to Amazon S3 and S3 Object Lambda- List
Objects V2Context Builder - Use builder syntax to set the inputs and finish with
build(). - S3Object
Lambda Event S3ObjectLambdaEventcontains data coming from S3 object lambdas See: https://docs.aws.amazon.com/AmazonS3/latest/userguide/olap-writing-lambda.html- S3Object
Lambda Event Builder - Use builder syntax to set the inputs and finish with
build(). - Session
Context - Session
Context Builder - Use builder syntax to set the inputs and finish with
build(). - Session
Issuer - Session
Issuer Builder - Use builder syntax to set the inputs and finish with
build(). - User
Identity UserIdentitycontains details about the identity that made the call to S3 Object Lambda- User
Identity Builder - Use builder syntax to set the inputs and finish with
build(). - User
Request UserRequestcontains information about the original call to S3 Object Lambda- User
Request Builder - Use builder syntax to set the inputs and finish with
build().